@@ -9,10 +9,14 @@ from cohesity_management_sdk.http.auth.auth_manager import AuthManager
 from cohesity_management_sdk.models.cluster_public_keys import ClusterPublicKeys
 from cohesity_management_sdk.models.create_cluster_result import CreateClusterResult
 from cohesity_management_sdk.models.cluster_creation_progress_result import ClusterCreationProgressResult
+from cohesity_management_sdk.models.bandwidth_limit import BandwidthLimit
+from cohesity_management_sdk.models.io_preferential_tier import IoPreferentialTier
+from cohesity_management_sdk.models.service_state_result import ServiceStateResult
 from cohesity_management_sdk.models.change_service_state_result import ChangeServiceStateResult
 from cohesity_management_sdk.models.upgrade_cluster_result import UpgradeClusterResult
 from cohesity_management_sdk.models.external_client_subnets import ExternalClientSubnets
 from cohesity_management_sdk.exceptions.request_error_error_exception import RequestErrorErrorException
+from cohesity_management_sdk.exceptions.error_exception import ErrorException
 
 
 class ClustersController(BaseController):
@@ -22,6 +26,62 @@ class ClustersController(BaseController):
         self.logger = logging.getLogger(__name__)
         self.config = config
 
+    def get_background_activity_schedule(self):
+        """Does a GET request to /public/cluster/backgroundActivitySchedule.
+
+        Sends a request to get the apollo throttling settings applied for
+        the cluster.
+
+        Returns:
+            BandwidthLimit: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('get_background_activity_schedule called.')
+
+            # Prepare query URL
+            self.logger.info(
+                'Preparing query URL for get_background_activity_schedule.')
+            _url_path = '/public/cluster/backgroundActivitySchedule'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info(
+                'Preparing headers for get_background_activity_schedule.')
+            _headers = {'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for ' + \
+                'get_background_activity_schedule.')
+            _request = self.http_client.get(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(
+                _request, name='get_background_activity_schedule')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for get_background_activity_schedule.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body, BandwidthLimit.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
     def get_cluster_keys(self):
         """Does a GET request to /public/cluster/keys.
 
@@ -320,6 +380,180 @@ class ClustersController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
+
+    def get_io_preferential_tier(self):
+        """Does a GET request to /public/clusters/ioPreferentialTier.
+
+        Get the IO preferential tiers of the cluster.
+
+        Returns:
+            IoPreferentialTier: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('get_io_preferential_tier called.')
+
+            # Prepare query URL
+            self.logger.info(
+                'Preparing query URL for get_io_preferential_tier.')
+            _url_path = '/public/clusters/ioPreferentialTier'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for get_io_preferential_tier.')
+            _headers = {'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for get_io_preferential_tier.'
+            )
+            _request = self.http_client.get(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='get_io_preferential_tier')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for get_io_preferential_tier.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body, IoPreferentialTier.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
+    def put_io_preferential_tier(self, body):
+        """Does a PUT request to /public/clusters/ioPreferentialTier.
+
+        Update the IO preferential tiers of the cluster.
+
+        Args:
+            body (IoPreferentialTier): TODO: type description here. Example:
+
+        Returns:
+            IoPreferentialTier: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('put_io_preferential_tier called.')
+
+            # Validate required parameters
+            self.logger.info(
+                'Validating required parameters for put_io_preferential_tier.')
+            self.validate_parameters(body=body)
+
+            # Prepare query URL
+            self.logger.info(
+                'Preparing query URL for put_io_preferential_tier.')
+            _url_path = '/public/clusters/ioPreferentialTier'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for put_io_preferential_tier.')
+            _headers = {
+                'accept': 'application/json',
+                'content-type': 'application/json; charset=utf-8'
+            }
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for put_io_preferential_tier.'
+            )
+            _request = self.http_client.put(
+                _query_url,
+                headers=_headers,
+                parameters=APIHelper.json_serialize(body))
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='put_io_preferential_tier')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for put_io_preferential_tier.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body, IoPreferentialTier.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
+    def remove_node(self, id):
+        """Does a DELETE request to /public/clusters/nodes/{id}.
+
+        Sends a request to remove a Node from a Cohesity Cluster.
+
+        Args:
+            id (long|int): Specifies the ID of the node being removed.
+
+        Returns:
+            void: Response from the API. No Content
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('remove_node called.')
+
+            # Validate required parameters
+            self.logger.info('Validating required parameters for remove_node.')
+            self.validate_parameters(id=id)
+
+            # Prepare query URL
+            self.logger.info('Preparing query URL for remove_node.')
+            _url_path = '/public/clusters/nodes/{id}'
+            _url_path = APIHelper.append_url_with_template_parameters(
+                _url_path, {'id': id})
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for remove_node.')
+            _request = self.http_client.delete(_query_url)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request, name='remove_node')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for remove_node.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
     def create_physical_cluster(self, body):
         """Does a POST request to /public/clusters/physicalEdition.
 
@@ -467,6 +701,58 @@ class ClustersController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
+    def list_service_states(self):
+        """Does a GET request to /public/clusters/services/states.
+
+        Sends a request to list the states of all of the services on a
+        Cluster.
+
+        Returns:
+            list of ServiceStateResult: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('list_service_states called.')
+
+            # Prepare query URL
+            self.logger.info('Preparing query URL for list_service_states.')
+            _url_path = '/public/clusters/services/states'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for list_service_states.')
+            _headers = {'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for list_service_states.')
+            _request = self.http_client.get(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='list_service_states')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for list_service_states.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body, ServiceStateResult.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
     def change_service_state(self, body):
         """Does a POST request to /public/clusters/services/states.
 
