@@ -7,10 +7,8 @@ from cohesity_management_sdk.configuration import Configuration
 from cohesity_management_sdk.controllers.base_controller import BaseController
 from cohesity_management_sdk.http.auth.auth_manager import AuthManager
 from cohesity_management_sdk.models.create_bond_result import CreateBondResult
-from cohesity_management_sdk.models.update_bond_result import UpdateBondResult
 from cohesity_management_sdk.models.host_result import HostResult
 from cohesity_management_sdk.models.host_entry import HostEntry
-from cohesity_management_sdk.models.node_network_interfaces import NodeNetworkInterfaces
 from cohesity_management_sdk.exceptions.request_error_error_exception import RequestErrorErrorException
 
 
@@ -86,71 +84,6 @@ class NetworkController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
-    def update_bond(self, body):
-        """Does a PUT request to /public/network/bonds.
-
-        Sends a request to update the bonding mode of a network bond. This can
-        only be
-        performed on a Node before it is part of a Cluster.
-
-        Args:
-            body (UpdateBondParameters): TODO: type description here. Example:
-
-        Returns:
-            UpdateBondResult: Response from the API. Success
-
-        Raises:
-            APIException: When an error occurs while fetching the data from
-                the remote API. This exception includes the HTTP Response
-                code, an error message, and the HTTP body that was received in
-                the request.
-
-        """
-        try:
-            self.logger.info('update_bond called.')
-
-            # Validate required parameters
-            self.logger.info('Validating required parameters for update_bond.')
-            self.validate_parameters(body=body)
-
-            # Prepare query URL
-            self.logger.info('Preparing query URL for update_bond.')
-            _url_path = '/public/network/bonds'
-            _query_builder = self.config.get_base_uri()
-            _query_builder += _url_path
-            _query_url = APIHelper.clean_url(_query_builder)
-
-            # Prepare headers
-            self.logger.info('Preparing headers for update_bond.')
-            _headers = {
-                'accept': 'application/json',
-                'content-type': 'application/json; charset=utf-8'
-            }
-
-            # Prepare and execute request
-            self.logger.info(
-                'Preparing and executing request for update_bond.')
-            _request = self.http_client.put(
-                _query_url,
-                headers=_headers,
-                parameters=APIHelper.json_serialize(body))
-            AuthManager.apply(_request, self.config)
-            _context = self.execute_request(_request, name='update_bond')
-
-            # Endpoint and global error handling using HTTP status codes.
-            self.logger.info('Validating response for update_bond.')
-            if _context.response.status_code == 0:
-                raise RequestErrorErrorException('Error', _context)
-            self.validate_response(_context)
-
-            # Return appropriate type
-            return APIHelper.json_deserialize(_context.response.raw_body,
-                                              UpdateBondResult.from_dictionary)
-
-        except Exception as e:
-            self.logger.error(e, exc_info=True)
-            raise
-
     def delete_bond(self, name):
         """Does a DELETE request to /public/network/bonds/{name}.
 
@@ -452,58 +385,3 @@ class NetworkController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
-    def list_network_interfaces(self):
-        """Does a GET request to /public/network/interfaces.
-
-        Sends a request to a Cluster to list all of the network interfaces
-        present
-        on the Cluster.
-
-        Returns:
-            list of NodeNetworkInterfaces: Response from the API. Success
-
-        Raises:
-            APIException: When an error occurs while fetching the data from
-                the remote API. This exception includes the HTTP Response
-                code, an error message, and the HTTP body that was received in
-                the request.
-
-        """
-        try:
-            self.logger.info('list_network_interfaces called.')
-
-            # Prepare query URL
-            self.logger.info(
-                'Preparing query URL for list_network_interfaces.')
-            _url_path = '/public/network/interfaces'
-            _query_builder = self.config.get_base_uri()
-            _query_builder += _url_path
-            _query_url = APIHelper.clean_url(_query_builder)
-
-            # Prepare headers
-            self.logger.info('Preparing headers for list_network_interfaces.')
-            _headers = {'accept': 'application/json'}
-
-            # Prepare and execute request
-            self.logger.info(
-                'Preparing and executing request for list_network_interfaces.')
-            _request = self.http_client.get(_query_url, headers=_headers)
-            AuthManager.apply(_request, self.config)
-            _context = self.execute_request(_request,
-                                            name='list_network_interfaces')
-
-            # Endpoint and global error handling using HTTP status codes.
-            self.logger.info(
-                'Validating response for list_network_interfaces.')
-            if _context.response.status_code == 0:
-                raise RequestErrorErrorException('Error', _context)
-            self.validate_response(_context)
-
-            # Return appropriate type
-            return APIHelper.json_deserialize(
-                _context.response.raw_body,
-                NodeNetworkInterfaces.from_dictionary)
-
-        except Exception as e:
-            self.logger.error(e, exc_info=True)
-            raise
