@@ -19,12 +19,13 @@ class ProtectionPoliciesController(BaseController):
         self.config = config
 
     def get_protection_policies(self,
-                                tenant_ids=None,
-                                all_under_hierarchy=None,
                                 ids=None,
                                 names=None,
                                 environments=None,
-                                vault_ids=None):
+                                vault_ids=None,
+                                origin=None,
+                                tenant_ids=None,
+                                all_under_hierarchy=None):
         """Does a GET request to /public/protectionPolicies.
 
         If no parameters are specified, all Protection Policies currently on
@@ -33,11 +34,6 @@ class ProtectionPoliciesController(BaseController):
         Specifying parameters filters the results that are returned.
 
         Args:
-            tenant_ids (list of string, optional): TenantIds contains ids of
-                the tenants for which objects are to be returned.
-            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
-                if objects of all the tenants under the hierarchy of the
-                logged in user's organization should be returned.
             ids (list of string, optional): Filter by a list of Protection
                 Policy ids.
             names (list of string, optional): Filter by a list of Protection
@@ -50,6 +46,15 @@ class ProtectionPoliciesController(BaseController):
             vault_ids (list of long|int, optional): Filter by a list of Vault
                 ids. Policies archiving to any of the specified vaults will be
                 returned.
+            origin (OriginEnum, optional): Specifies the origin of the
+                protection policy of the protection policy. 'kHelios' means a
+                global policy which was created on Helios. 'kLocal' means a
+                local policy which was created on the cluster.
+            tenant_ids (list of string, optional): TenantIds contains ids of
+                the tenants for which objects are to be returned.
+            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
+                if objects of all the tenants under the hierarchy of the
+                logged in user's organization should be returned.
 
         Returns:
             list of ProtectionPolicy: Response from the API. Success
@@ -71,12 +76,13 @@ class ProtectionPoliciesController(BaseController):
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_parameters = {
-                'tenantIds': tenant_ids,
-                'allUnderHierarchy': all_under_hierarchy,
                 'ids': ids,
                 'names': names,
                 'environments': environments,
-                'vaultIds': vault_ids
+                'vaultIds': vault_ids,
+                'origin': origin,
+                'tenantIds': tenant_ids,
+                'allUnderHierarchy': all_under_hierarchy
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
