@@ -11,9 +11,11 @@ from cohesity_management_sdk.models.protection_source_node import ProtectionSour
 from cohesity_management_sdk.models.registered_application_server import RegisteredApplicationServer
 from cohesity_management_sdk.models.protection_source import ProtectionSource
 from cohesity_management_sdk.models.protected_vm_info import ProtectedVmInfo
+from cohesity_management_sdk.models.run_diagnostics_message import RunDiagnosticsMessage
 from cohesity_management_sdk.models.get_registration_info_response import GetRegistrationInfoResponse
 from cohesity_management_sdk.models.sql_aag_host_and_databases import SqlAagHostAndDatabases
 from cohesity_management_sdk.exceptions.request_error_error_exception import RequestErrorErrorException
+from cohesity_management_sdk.models.exchange_dag_hosts_response import ExchangeDagHostsResponse
 
 
 class ProtectionSourcesController(BaseController):
@@ -23,7 +25,10 @@ class ProtectionSourcesController(BaseController):
         self.logger = logging.getLogger(__name__)
         self.config = config
 
-    def get_download_physical_agent(self, host_type, pkg_type=None):
+    def get_download_physical_agent(self,
+                                    host_type,
+                                    pkg_type=None,
+                                    agent_type=None):
         """Does a GET request to /public/physicalAgents/download.
 
         Host type could be Linux, Windows, AIX.
@@ -34,13 +39,19 @@ class ProtectionSourcesController(BaseController):
                 'kLinux' indicates the Linux operating system. 'kWindows'
                 indicates the Microsoft Windows operating system. 'kAix'
                 indicates the IBM AIX operating system. 'kSolaris' indicates
-                the Oracle Solaris operating system.
+                the Oracle Solaris operating system. 'kSapHana' indicates the
+                Sap Hana database system developed by SAP SE. 'kOther'
+                indicates the other types of operating system.
             pkg_type (PkgTypeEnum, optional): Specifies the Linux installer
                 package type applicable only to Linux OS and the value can be
                 any of ("kScript","kRPM", "kSuseRPM", "kDEB") 'kScript'
                 indicates a script based agent installer. 'kRPM' indicates a
                 RPM agent installer. 'kSuseRPM' indicates a Open Suse RPM
                 installer. 'kDEB' indicates a Debian agent installer.
+            agent_type (AgentTypeEnum, optional): Specifies agent type. Can be
+                "kGo" for go agent and "kJava" for java agent and "kCpp" for
+                c++ agent. 'kCpp' indicates a c++ agent. 'kJava' indicates a
+                java agent. 'kGo' indicates a go agent.
 
         Returns:
             list of int: Response from the API. Success
@@ -67,7 +78,11 @@ class ProtectionSourcesController(BaseController):
             _url_path = '/public/physicalAgents/download'
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
-            _query_parameters = {'hostType': host_type, 'pkgType': pkg_type}
+            _query_parameters = {
+                'hostType': host_type,
+                'pkgType': pkg_type,
+                'agentType': agent_type
+            }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
                 Configuration.array_serialization)
@@ -187,8 +202,6 @@ class ProtectionSourcesController(BaseController):
             raise
 
     def list_protection_sources(self,
-                                tenant_ids=None,
-                                all_under_hierarchy=None,
                                 after_cursor_entity_id=None,
                                 before_cursor_entity_id=None,
                                 node_id=None,
@@ -196,13 +209,16 @@ class ProtectionSourcesController(BaseController):
                                 id=None,
                                 exclude_types=None,
                                 exclude_office_365_types=None,
+                                exclude_aws_types=None,
                                 include_datastores=None,
                                 include_networks=None,
                                 include_vm_folders=None,
                                 environments=None,
                                 environment=None,
                                 include_entity_permission_info=None,
-                                sids=None):
+                                sids=None,
+                                tenant_ids=None,
+                                all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources.
 
         If no parameters are specified, all Protection Sources that are
@@ -213,16 +229,12 @@ class ProtectionSourcesController(BaseController):
         Server
         and creates an hierarchical Object subtree that mirrors the
         Inventory tree on vCenter Server.
-        The contents of the Object tree is returned as a "nodes" hierarchy
+        The contents of the Object tree are returned as a "nodes" hierarchy
         of "protectionSource"s.
         Specifying parameters can alter the results that are returned.
 
+
         Args:
-            tenant_ids (list of string, optional): TenantIds contains ids of
-                the tenants for which objects are to be returned.
-            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
-                if objects of all the tenants under the hierarchy of the
-                logged in user's organization should be returned.
             after_cursor_entity_id (long|int, optional): Specifies the entity
                 id starting from which the items are to be returned.
             before_cursor_entity_id (long|int, optional): Specifies the entity
@@ -246,6 +258,11 @@ class ProtectionSourcesController(BaseController):
                 Office 365 that match the passed in types such as 'kDomain',
                 'kOutlook', 'kMailbox', etc. For example, set this parameter
                 to 'kMailbox' to exclude Mailbox Objects from being returned.
+            exclude_aws_types (list of ExcludeAwsTypeEnum, optional): Specifies
+                the Object types to be filtered out for AWS that match the
+                passed in types such as 'kEC2Instance', 'kRDSInstance' etc.
+                For example, set this parameter to 'kEC2Instance' to exclude
+                ec2 instance from being returned.
             include_datastores (bool, optional): Set this parameter to true to
                 also return kDatastore object types found in the Source in
                 addition to their Object subtrees. By default, datastores are
@@ -274,6 +291,11 @@ class ProtectionSourcesController(BaseController):
                 returned.
             sids (list of string, optional): Filter the object subtree for the
                 sids given in the list.
+            tenant_ids (list of string, optional): TenantIds contains ids of
+                the tenants for which objects are to be returned.
+            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
+                if objects of all the tenants under the hierarchy of the
+                logged in user's organization should be returned.
 
         Returns:
             list of ProtectionSourceNode: Response from the API. Success
@@ -295,8 +317,6 @@ class ProtectionSourcesController(BaseController):
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_parameters = {
-                'tenantIds': tenant_ids,
-                'allUnderHierarchy': all_under_hierarchy,
                 'afterCursorEntityId': after_cursor_entity_id,
                 'beforeCursorEntityId': before_cursor_entity_id,
                 'nodeId': node_id,
@@ -304,13 +324,16 @@ class ProtectionSourcesController(BaseController):
                 'id': id,
                 'excludeTypes': exclude_types,
                 'excludeOffice365Types': exclude_office_365_types,
+                'excludeAwsTypes': exclude_aws_types,
                 'includeDatastores': include_datastores,
                 'includeNetworks': include_networks,
                 'includeVMFolders': include_vm_folders,
                 'environments': environments,
                 'environment': environment,
                 'includeEntityPermissionInfo': include_entity_permission_info,
-                'sids': sids
+                'sids': sids,
+                'tenantIds': tenant_ids,
+                'allUnderHierarchy': all_under_hierarchy
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -373,31 +396,36 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kPuppeteer' indicates the Cohesity's Remote
                 Adapter. 'kPhysical' indicates the physical Protection Source
                 environment. 'kPure' indicates the Pure Storage Protection
-                Source environment. 'kAzure' indicates the Microsoft's Azure
-                Protection Source environment. 'kNetapp' indicates the Netapp
-                Protection Source environment. 'kAgent' indicates the Agent
-                Protection Source environment. 'kGenericNas' indicates the
-                Genreric Network Attached Storage Protection Source
-                environment. 'kAcropolis' indicates the Acropolis Protection
-                Source environment. 'kPhsicalFiles' indicates the Physical
-                Files Protection Source environment. 'kIsilon' indicates the
-                Dell EMC's Isilon Protection Source environment. 'kKVM'
-                indicates the KVM Protection Source environment. 'kAWS'
-                indicates the AWS Protection Source environment. 'kExchange'
-                indicates the Exchange Protection Source environment.
-                'kHyperVVSS' indicates the HyperV VSS Protection Source
-                environment. 'kOracle' indicates the Oracle Protection Source
-                environment. 'kGCP' indicates the Google Cloud Platform
-                Protection Source environment. 'kFlashBlade' indicates the
-                Flash Blade Protection Source environment. 'kAWSNative'
-                indicates the AWS Native Protection Source environment.
-                'kO365' indicates the Office 365 Protection Source
+                Source environment. 'Nimble' indicates the Nimble Storage
+                Protection Source environment. 'kAzure' indicates the
+                Microsoft's Azure Protection Source environment. 'kNetapp'
+                indicates the Netapp Protection Source environment. 'kAgent'
+                indicates the Agent Protection Source environment.
+                'kGenericNas' indicates the Generic Network Attached Storage
+                Protection Source environment. 'kAcropolis' indicates the
+                Acropolis Protection Source environment. 'kPhsicalFiles'
+                indicates the Physical Files Protection Source environment.
+                'kIsilon' indicates the Dell EMC's Isilon Protection Source
+                environment. 'kGPFS' indicates IBM's GPFS Protection Source
+                environment. 'kKVM' indicates the KVM Protection Source
+                environment. 'kAWS' indicates the AWS Protection Source
+                environment. 'kExchange' indicates the Exchange Protection
+                Source environment. 'kHyperVVSS' indicates the HyperV VSS
+                Protection Source environment. 'kOracle' indicates the Oracle
+                Protection Source environment. 'kGCP' indicates the Google
+                Cloud Platform Protection Source environment. 'kFlashBlade'
+                indicates the Flash Blade Protection Source environment.
+                'kAWSNative' indicates the AWS Native Protection Source
+                environment. 'kO365' indicates the Office 365 Protection Source
                 environment. 'kO365Outlook' indicates Office 365 outlook
-                Protection Source environment. 'kHyperFlex' indicates the
-                Hyper Flex Protection Source environment. 'kGCPNative'
-                indicates the GCP Native Protection Source environment.
-                'kAzureNative' indicates the Azure Native Protection Source
-                environment.
+                Protection Source environment. 'kHyperFlex' indicates the Hyper
+                Flex Protection Source environment. 'kGCPNative' indicates the
+                GCP Native Protection Source environment. 'kAzureNative'
+                indicates the Azure Native Protection Source environment.
+                'kKubernetes' indicates a Kubernetes Protection Source environment.
+                'kElastifile' indicates Elastifile Protection Source environment.
+                'kAD' indicates Active Directory Protection Source environment.
+                'kRDSSnapshotManager' indicates AWS RDS Protection Source environment.
             protection_source_id (long|int, optional): Specifies the
                 Protection Source Id of the 'kPhysical' or 'kVMware' entity in
                 the Protection Source tree hosting the applications.
@@ -412,15 +440,17 @@ class ProtectionSourcesController(BaseController):
                 Protection Source environment. 'kPuppeteer' indicates the
                 Cohesity's Remote Adapter. 'kPhysical' indicates the physical
                 Protection Source environment. 'kPure' indicates the Pure
-                Storage Protection Source environment. 'kAzure' indicates the
-                Microsoft's Azure Protection Source environment. 'kNetapp'
-                indicates the Netapp Protection Source environment. 'kAgent'
-                indicates the Agent Protection Source environment.
-                'kGenericNas' indicates the Genreric Network Attached Storage
+                Storage Protection Source environment. 'Nimble' indicates the
+                Nimble Storage Protection Source environment. 'kAzure'
+                indicates the Microsoft's Azure Protection Source environment.
+                'kNetapp' indicates the Netapp Protection Source environment.
+                'kAgent' indicates the Agent Protection Source environment.
+                'kGenericNas' indicates the Generic Network Attached Storage
                 Protection Source environment. 'kAcropolis' indicates the
                 Acropolis Protection Source environment. 'kPhsicalFiles'
                 indicates the Physical Files Protection Source environment.
                 'kIsilon' indicates the Dell EMC's Isilon Protection Source
+                environment. 'kGPFS' indicates IBM's GPFS Protection Source
                 environment. 'kKVM' indicates the KVM Protection Source
                 environment. 'kAWS' indicates the AWS Protection Source
                 environment. 'kExchange' indicates the Exchange Protection
@@ -430,12 +460,17 @@ class ProtectionSourcesController(BaseController):
                 Cloud Platform Protection Source environment. 'kFlashBlade'
                 indicates the Flash Blade Protection Source environment.
                 'kAWSNative' indicates the AWS Native Protection Source
-                environment. 'kO365' indicates the Office 365 Protection
-                Source environment. 'kO365Outlook' indicates Office 365
-                outlook Protection Source environment. 'kHyperFlex' indicates
-                the Hyper Flex Protection Source environment. 'kGCPNative'
-                indicates the GCP Native Protection Source environment.
-                'kAzureNative' indicates the Azure Native Protection Source
+                environment. 'kO365' indicates the
+                Office 365 Protection Source environment. 'kO365Outlook'
+                indicates Office 365 outlook Protection Source environment.
+                'kHyperFlex' indicates the Hyper Flex Protection Source
+                environment. 'kGCPNative' indicates the GCP Native Protection
+                Source environment. 'kAzureNative' indicates the Azure Native
+                Protection Source environment. 'kKubernetes' indicates a
+                Kubernetes Protection Source environment. 'kElastifile'
+                indicates Elastifile Protection Source environment.
+                'kAD' indicates Active Directory Protection Source environment.
+                'kRDSSnapshotManager' indicates AWS RDS Protection Source
                 environment.
 
         Returns:
@@ -796,6 +831,137 @@ class ProtectionSourcesController(BaseController):
             self.logger.error(e, exc_info=True)
             raise
 
+    def run_diagnostics(self, id):
+        """Does a POST request to /public/protectionSources/diagnostics/{id}
+
+        If the request is successful, the diagnostics script is triggered on
+        Cohesity
+        agent which generates a tarball containing various diagnostics and
+        uploads it
+        to the Cohesity cluster. Host type could be Linux, Windows.
+
+        Args:
+            id (int): Specifies the entity id.
+
+        Returns:
+            RunDiagnosticsMessage: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('run_diagnostics called.')
+
+            # Validate required parameters
+            self.logger.info(
+                'Validating required parameters for run_diagnostics.'
+            )
+            self.validate_parameters(id=id)
+
+            # Prepare query URL
+
+            _url_path = '/public/protectionSources/diagnostics/{id}'
+            _url_path = APIHelper.append_url_with_template_parameters(
+                _url_path, {'id': id})
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+            # Prepare headers
+            self.logger.info(
+                'Preparing headers for run_diagnostics.')
+            _headers = {
+                'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for run_diagnostics.'
+            )
+            _request = self.http_client.post(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request, name='run_diagnostics')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for run_diagnostics.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(_context.response.raw_body,
+                                              RunDiagnosticsMessage.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
+    def list_exchange_dag_hosts(self, endpoint=None, protection_source_id=None):
+        """Does a GET request to /public/protectionSources/exchangeDagHosts.
+
+        Returns information about all the exchange hosts that belong to an
+        Exchange
+        DAG.
+
+        Args:
+            endpoint (string, optional): Specifies the endpoint of Exchange
+                DAG or a host which is member of Exchange DAG or a standalone
+                exchange server.
+            protection_source_id (int): Specifies the Protection Source Id of
+                the Exchange DAG source.
+
+        Returns:
+            ExchangeDagHostsResponse: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('list_exchange_dag_hosts called.')
+
+            # Prepare query URL
+            self.logger.info('Preparing query URL for list_exchange_dag_hosts.')
+            _url_path = '/public/protectionSources/exchangeDagHosts'
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_parameters = {'endpoint': endpoint, 'protectionSourceId': protection_source_id}
+            _query_builder = APIHelper.append_url_with_query_parameters(
+                _query_builder, _query_parameters,
+                Configuration.array_serialization)
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for list_exchange_dag_hosts.')
+            _headers = {'accept': 'application/json'}
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for list_exchange_dag_hosts.')
+            _request = self.http_client.get(_query_url, headers=_headers)
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request, name='list_exchange_dag_hosts')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info('Validating response for list_exchange_dag_hosts.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(_context.response.raw_body,
+                                              ExchangeDagHostsResponse.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
+
     def get_protection_sources_objects(self, object_ids=None):
         """Does a GET request to /public/protectionSources/objects.
 
@@ -954,31 +1120,35 @@ class ProtectionSourcesController(BaseController):
                 environment. 'kPuppeteer' indicates the Cohesity's Remote
                 Adapter. 'kPhysical' indicates the physical Protection Source
                 environment. 'kPure' indicates the Pure Storage Protection
-                Source environment. 'kAzure' indicates the Microsoft's Azure
-                Protection Source environment. 'kNetapp' indicates the Netapp
-                Protection Source environment. 'kAgent' indicates the Agent
-                Protection Source environment. 'kGenericNas' indicates the
-                Genreric Network Attached Storage Protection Source
-                environment. 'kAcropolis' indicates the Acropolis Protection
-                Source environment. 'kPhsicalFiles' indicates the Physical
-                Files Protection Source environment. 'kIsilon' indicates the
-                Dell EMC's Isilon Protection Source environment. 'kKVM'
-                indicates the KVM Protection Source environment. 'kAWS'
-                indicates the AWS Protection Source environment. 'kExchange'
-                indicates the Exchange Protection Source environment.
-                'kHyperVVSS' indicates the HyperV VSS Protection Source
-                environment. 'kOracle' indicates the Oracle Protection Source
-                environment. 'kGCP' indicates the Google Cloud Platform
-                Protection Source environment. 'kFlashBlade' indicates the
-                Flash Blade Protection Source environment. 'kAWSNative'
-                indicates the AWS Native Protection Source environment.
-                'kO365' indicates the Office 365 Protection Source
-                environment. 'kO365Outlook' indicates Office 365 outlook
-                Protection Source environment. 'kHyperFlex' indicates the
-                Hyper Flex Protection Source environment. 'kGCPNative'
-                indicates the GCP Native Protection Source environment.
-                'kAzureNative' indicates the Azure Native Protection Source
-                environment.
+                Source environment. 'Nimble' indicates the Nimble Storage
+                Protection Source environment. 'kAzure' indicates the
+                Microsoft's Azure Protection Source environment. 'kNetapp'
+                indicates the Netapp Protection Source environment. 'kAgent'
+                indicates the Agent Protection Source environment.
+                'kGenericNas' indicates the Generic Network Attached Storage
+                Protection Source environment. 'kAcropolis' indicates the
+                Acropolis Protection Source environment. 'kPhsicalFiles'
+                indicates the Physical Files Protection Source environment.
+                'kIsilon' indicates the Dell EMC's Isilon Protection Source
+                environment. 'kGPFS' indicates IBM's GPFS Protection Source
+                environment. 'kKVM' indicates the KVM Protection Source
+                environment. 'kAWS' indicates the AWS Protection Source
+                environment. 'kExchange' indicates the Exchange Protection
+                Source environment. 'kHyperVVSS' indicates the HyperV VSS
+                Protection Source environment. 'kOracle' indicates the Oracle
+                Protection Source environment. 'kGCP' indicates the Google
+                Cloud Platform Protection Source environment. 'kFlashBlade'
+                indicates the Flash Blade Protection Source environment.
+                'kAWSNative' indicates the AWS Native Protection Source
+                environment. 'kO365' indicates the
+                Office 365 Protection Source environment. 'kO365Outlook'
+                indicates Office 365 outlook Protection Source environment.
+                'kHyperFlex' indicates the Hyper Flex Protection Source
+                environment. 'kGCPNative' indicates the GCP Native Protection
+                Source environment. 'kAzureNative' indicates the Azure Native
+                Protection Source environment. 'kKubernetes' indicates a
+                Kubernetes Protection Source environment. 'kElastifile'
+                indicates Elastifile Protection Source environment.
             id (long|int): Specifies the Id of a registered Protection Source
                 of the type given in environment.
             all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
@@ -1055,14 +1225,19 @@ class ProtectionSourcesController(BaseController):
         tree
         on the Cohesity Cluster and the Inventory tree
         in the associated vCenter Server.
+
         For example if a new VM is added to the vCenter Server, after a
         refresh,
         a new Protection Source node for this VM is added to the Protection
         Sources
         tree.
-        Success indicates the forced refresh has been started. The amount of
-        time to
-        complete a refresh depends on the size of the Object hierarchies.
+
+        Success indicates the forced refresh has been completed. For larger
+        sources it
+        is possible for the operation to timeout before the force refresh has
+        been
+        completed. This timeout can be increased by modifying the
+        'iris_post_timeout_msecs_to_magneto' gflag on the Iris service.
 
         Args:
             id (long|int): Id of the root node of the Protection Sources tree
@@ -1124,7 +1299,7 @@ class ProtectionSourcesController(BaseController):
         """Does a POST request to /public/protectionSources/register.
 
         Register a Protection Source on the Cohesity Cluster.
-        It could be the root node of a vCenter Server or a physcical server.
+        It could be the root node of a vCenter Server or a physical server.
         Returns the newly registered Protection Source upon success.
 
         Args:
@@ -1195,23 +1370,18 @@ class ProtectionSourcesController(BaseController):
 
     def list_protection_sources_registration_info(
         self,
-        tenant_ids=None,
-        all_under_hierarchy=None,
         environments=None,
         ids=None,
         include_entity_permission_info=None,
-        sids=None):
+        sids=None,
+        tenant_ids=None,
+        all_under_hierarchy=None):
         """Does a GET request to /public/protectionSources/registrationInfo.
 
         Returns the registration and protection information of the registered
         Protection Sources.
 
         Args:
-            tenant_ids (list of string, optional): TenantIds contains ids of
-                the tenants for which objects are to be returned.
-            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
-                if objects of all the tenants under the hierarchy of the
-                logged in user's organization should be returned.
             environments (list of
                 EnvironmentListProtectionSourcesRegistrationInfoEnum,
                 optional): Return only Protection Sources that match the
@@ -1225,10 +1395,15 @@ class ProtectionSourcesController(BaseController):
             ids (list of long|int, optional): Return only the registered root
                 nodes whose Ids are given in the list.
             include_entity_permission_info (bool, optional): If specified,
-                then a list of entites with permissions assigned to them are
+                then a list of entities with permissions assigned to them are
                 returned.
             sids (list of string, optional): Filter the registered root nodes
                 for the sids given in the list.
+            tenant_ids (list of string, optional): TenantIds contains ids of
+                the tenants for which objects are to be returned.
+            all_under_hierarchy (bool, optional): AllUnderHierarchy specifies
+                if objects of all the tenants under the hierarchy of the
+                logged in user's organization should be returned.
 
         Returns:
             GetRegistrationInfoResponse: Response from the API. Success
@@ -1252,12 +1427,12 @@ class ProtectionSourcesController(BaseController):
             _query_builder = self.config.get_base_uri()
             _query_builder += _url_path
             _query_parameters = {
-                'tenantIds': tenant_ids,
-                'allUnderHierarchy': all_under_hierarchy,
                 'environments': environments,
                 'ids': ids,
                 'includeEntityPermissionInfo': include_entity_permission_info,
-                'sids': sids
+                'sids': sids,
+                'tenantIds': tenant_ids,
+                'allUnderHierarchy': all_under_hierarchy
             }
             _query_builder = APIHelper.append_url_with_query_parameters(
                 _query_builder, _query_parameters,
@@ -1607,3 +1782,77 @@ Success
         except Exception as e:
             self.logger.error(e, exc_info=True)
             raise
+
+    def update_protection_source(self, id, body=None):
+        """Does a PATCH request to /public/protectionSources/{id}.
+
+        Update a previously registered Protection Source with new details.
+
+        Args:
+            id (long|int): Specifies a unique id of the Protection Source to
+                update.
+            body (UpdateProtectionSourceParameters, optional): Request to
+                update protection source.
+
+        Returns:
+            ProtectionSourceNode: Response from the API. Success
+
+        Raises:
+            APIException: When an error occurs while fetching the data from
+                the remote API. This exception includes the HTTP Response
+                code, an error message, and the HTTP body that was received in
+                the request.
+
+        """
+        try:
+            self.logger.info('update_protection_source called.')
+
+            # Validate required parameters
+            self.logger.info(
+                'Validating required parameters for update_protection_source.')
+            self.validate_parameters(id=id)
+
+            # Prepare query URL
+            self.logger.info(
+                'Preparing query URL for update_protection_source.')
+            _url_path = '/public/protectionSources/{id}'
+            _url_path = APIHelper.append_url_with_template_parameters(
+                _url_path, {'id': id})
+            _query_builder = self.config.get_base_uri()
+            _query_builder += _url_path
+            _query_url = APIHelper.clean_url(_query_builder)
+
+            # Prepare headers
+            self.logger.info('Preparing headers for update_protection_source.')
+            _headers = {
+                'accept': 'application/json',
+                'content-type': 'application/json; charset=utf-8'
+            }
+
+            # Prepare and execute request
+            self.logger.info(
+                'Preparing and executing request for update_protection_source.'
+            )
+            _request = self.http_client.patch(
+                _query_url,
+                headers=_headers,
+                parameters=APIHelper.json_serialize(body))
+            AuthManager.apply(_request, self.config)
+            _context = self.execute_request(_request,
+                                            name='update_protection_source')
+
+            # Endpoint and global error handling using HTTP status codes.
+            self.logger.info(
+                'Validating response for update_protection_source.')
+            if _context.response.status_code == 0:
+                raise RequestErrorErrorException('Error', _context)
+            self.validate_response(_context)
+
+            # Return appropriate type
+            return APIHelper.json_deserialize(
+                _context.response.raw_body,
+                ProtectionSourceNode.from_dictionary)
+
+        except Exception as e:
+            self.logger.error(e, exc_info=True)
+            raise
