@@ -5,9 +5,8 @@ class ApplicationEnvironmentEnum(object):
 
     """Implementation of the 'ApplicationEnvironment' enum.
 
-    Specifies the Environment of the Application to restore like 'kSQL', or
-    'kExchange'.
-    overrideDescription: true
+    Specifies the Environment of the Application server to restore like
+    'kSQL','kAD',or 'kExchange'.
     Supported environment types such as 'kView', 'kSQL', 'kVMware', etc.
     NOTE: 'kPuppeteer' refers to Cohesity's Remote Adapter.
     'kVMware' indicates the VMware Protection Source environment.
@@ -17,15 +16,17 @@ class ApplicationEnvironmentEnum(object):
     'kPuppeteer' indicates the Cohesity's Remote Adapter.
     'kPhysical' indicates the physical Protection Source environment.
     'kPure' indicates the Pure Storage Protection Source environment.
+    'Nimble' indicates the Nimble Storage Protection Source environment.
     'kAzure' indicates the Microsoft's Azure Protection Source environment.
     'kNetapp' indicates the Netapp Protection Source environment.
     'kAgent' indicates the Agent Protection Source environment.
-    'kGenericNas' indicates the Genreric Network Attached Storage Protection
+    'kGenericNas' indicates the Generic Network Attached Storage Protection
     Source environment.
     'kAcropolis' indicates the Acropolis Protection Source environment.
     'kPhsicalFiles' indicates the Physical Files Protection Source
     environment.
     'kIsilon' indicates the Dell EMC's Isilon Protection Source environment.
+    'kGPFS' indicates IBM's GPFS Protection Source environment.
     'kKVM' indicates the KVM Protection Source environment.
     'kAWS' indicates the AWS Protection Source environment.
     'kExchange' indicates the Exchange Protection Source environment.
@@ -41,6 +42,11 @@ class ApplicationEnvironmentEnum(object):
     'kHyperFlex' indicates the Hyper Flex Protection Source environment.
     'kGCPNative' indicates the GCP Native Protection Source environment.
     'kAzureNative' indicates the Azure Native Protection Source environment.
+    'kKubernetes' indicates a Kubernetes Protection Source environment.
+    'kElastifile' indicates Elastifile Protection Source environment.
+    'kAD' indicates Active Directory Protection Source environment.
+    'kRDSSnapshotManager' indicates AWS RDS Protection Source
+    environment.
 
     Attributes:
         KVMWARE: TODO: type description here.
@@ -50,6 +56,7 @@ class ApplicationEnvironmentEnum(object):
         KPUPPETEER: TODO: type description here.
         KPHYSICAL: TODO: type description here.
         KPURE: TODO: type description here.
+        KNIMBLE: TODO: type description here.
         KAZURE: TODO: type description here.
         KNETAPP: TODO: type description here.
         KAGENT: TODO: type description here.
@@ -57,6 +64,7 @@ class ApplicationEnvironmentEnum(object):
         KACROPOLIS: TODO: type description here.
         KPHYSICALFILES: TODO: type description here.
         KISILON: TODO: type description here.
+        KGPFS: TODO: type description here.
         KKVM: TODO: type description here.
         KAWS: TODO: type description here.
         KEXCHANGE: TODO: type description here.
@@ -70,6 +78,10 @@ class ApplicationEnvironmentEnum(object):
         KHYPERFLEX: TODO: type description here.
         KGCPNATIVE: TODO: type description here.
         KAZURENATIVE: TODO: type description here.
+        KKUBERNETES: TODO: type description here.
+        KELASTIFILE: TODO: type description here.
+        KAD: TODO: type description here.
+        KRDSSNAPSHOTMANAGER: TODO: type description here.
 
     """
 
@@ -87,6 +99,8 @@ class ApplicationEnvironmentEnum(object):
 
     KPURE = 'kPure'
 
+    KNIMBLE = 'kNimble'
+
     KAZURE = 'kAzure'
 
     KNETAPP = 'kNetapp'
@@ -101,6 +115,8 @@ class ApplicationEnvironmentEnum(object):
 
     KISILON = 'kIsilon'
 
+    KGPFS = 'kGPFS'
+
     KKVM = 'kKVM'
 
     KAWS = 'kAWS'
@@ -127,3 +143,11 @@ class ApplicationEnvironmentEnum(object):
 
     KAZURENATIVE = 'kAzureNative'
 
+    KKUBERNETES = 'kKubernetes'
+
+    KELASTIFILE = 'kElastifile'
+
+    KAD = 'kAD'
+
+    KRDSSNAPSHOTMANAGER = 'kRDSSnapshotManager'
+
