@@ -16,6 +16,7 @@ import cohesity_management_sdk.models.backup_job_proto_backup_source
 import cohesity_management_sdk.models.time
 import cohesity_management_sdk.models.stubbing_policy_proto
 import cohesity_management_sdk.models.user_information
+import cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude
 
 class BackupJobProto(object):
 
@@ -67,8 +68,7 @@ class BackupJobProto(object):
         exclude_sources_deprecated (list of EntityProto): The list of sources
             to exclude from backups. These can have non-leaf-level entities,
             but it's up to the creator to ensure that a child of these sources
-            hasn't been explicitly added to 'sources'. TODO(Chinmaya): Remove
-            after removing references.
+            hasn't been explicitly added to 'sources'.
         exclusion_ranges (list of BackupJobProtoExclusionTimeRange): Do not
             run backups in these time-ranges.
         full_backup_job_policy (JobPolicyProto): A message that specifies the
@@ -78,6 +78,9 @@ class BackupJobProto(object):
             for full backups that are excepted i.e either scheduled or the
             first full backup and not for full backups that happen as a result
             of incremental backup failure.
+        global_include_exclude (PhysicalFileBackupParams_GlobalIncludeExclude):
+            Determines global include and exclude filters
+            which are applied to all sources in a job.
         indexing_policy (IndexingPolicyProto): Proto to encapsulate file level
             indexing policy for VMs in a backup job.
         is_active (bool): Whether the backup job is active or not. Details
@@ -85,6 +88,11 @@ class BackupJobProto(object):
             https://goo.gl/1mLvS3.
         is_deleted (bool): Tracks whether the backup job has actually been
             deleted.
+        is_direct_archive_enabled (bool): This field is set to true if this is
+            a direct archive backup job.
+        is_direct_archive_native_format_enabled (bool): This field is set to
+            true if native format should be used for archiving. Applicable for
+            only direct archive jobs.
         is_paused (bool): Whether the backup job is paused. New backup runs
             are not scheduled for the paused backup job. Active run of a
             backup job (if any) is not impacted.
@@ -167,7 +175,18 @@ class BackupJobProto(object):
         remote_job_uids (list of UniversalIdProto): The globally unique ids of
             all remote jobs that are linked to this job (because of incoming
             replications). This field will only be populated for locally
-            created jobs.
+            created jobs. This field is populated only for the local(stub) job
+            during incoming replications. In the most common case of one
+            cluster replicating to another, this field will only have one
+            entry (which is the id of the job on Tx side) and matches the
+            primary_job_uid. This will have multiple entries in the following
+            situation: A->B, A->C replication. The backup is failed over to B,
+            and B now starts replicating to C. In this case, the stub job at C
+            will have two entries. One is the job id from cluster A, and
+            another is the local(stub) job uid from B. Also note that since
+            the job originated from A, primary_job_uid for all the replicated
+            instances of this job across multiple clusters will remain the
+            same (which is equal to the job id from the original cluster A).
         remote_view_name (string): A human readable name of the remote view. A
             remote view is created with name overwriting the latest snapshot.
         required_feature_vec (list of string): The features that are strictly
@@ -237,9 +256,12 @@ class BackupJobProto(object):
         "exclusion_ranges":'exclusionRanges',
         "full_backup_job_policy":'fullBackupJobPolicy',
         "full_backup_sla_time_mins":'fullBackupSlaTimeMins',
+        "global_include_exclude":'globalIncludeExclude',
         "indexing_policy":'indexingPolicy',
         "is_active":'isActive',
         "is_deleted":'isDeleted',
+        "is_direct_archive_enabled":'isDirectArchiveEnabled',
+        "is_direct_archive_native_format_enabled":'isDirectArchiveNativeFormatEnabled',
         "is_paused":'isPaused',
         "is_rpo_job":'isRpoJob',
         "job_creation_time_usecs":'jobCreationTimeUsecs',
@@ -299,9 +321,12 @@ class BackupJobProto(object):
                  exclusion_ranges=None,
                  full_backup_job_policy=None,
                  full_backup_sla_time_mins=None,
+                 global_include_exclude=None,
                  indexing_policy=None,
                  is_active=None,
                  is_deleted=None,
+                 is_direct_archive_enabled=None,
+                 is_direct_archive_native_format_enabled=None,
                  is_paused=None,
                  is_rpo_job=None,
                  job_creation_time_usecs=None,
@@ -361,9 +386,12 @@ class BackupJobProto(object):
         self.exclusion_ranges = exclusion_ranges
         self.full_backup_job_policy = full_backup_job_policy
         self.full_backup_sla_time_mins = full_backup_sla_time_mins
+        self.global_include_exclude = global_include_exclude
         self.indexing_policy = indexing_policy
         self.is_active = is_active
         self.is_deleted = is_deleted
+        self.is_direct_archive_enabled = is_direct_archive_enabled
+        self.is_direct_archive_native_format_enabled = is_direct_archive_native_format_enabled
         self.is_paused = is_paused
         self.is_rpo_job = is_rpo_job
         self.job_creation_time_usecs = job_creation_time_usecs
@@ -456,9 +484,12 @@ class BackupJobProto(object):
                 exclusion_ranges.append(cohesity_management_sdk.models.backup_job_proto_exclusion_time_range.BackupJobProtoExclusionTimeRange.from_dictionary(structure))
         full_backup_job_policy = cohesity_management_sdk.models.job_policy_proto.JobPolicyProto.from_dictionary(dictionary.get('fullBackupJobPolicy')) if dictionary.get('fullBackupJobPolicy') else None
         full_backup_sla_time_mins = dictionary.get('fullBackupSlaTimeMins')
+        global_include_exclude = cohesity_management_sdk.models.physical_file_backup_params_global_include_exclude.PhysicalFileBackupParams_GlobalIncludeExclude.from_dictionary(dictionary.get('globalIncludeExclude')) if dictionary.get('globalIncludeExclude') else None
         indexing_policy = cohesity_management_sdk.models.indexing_policy_proto.IndexingPolicyProto.from_dictionary(dictionary.get('indexingPolicy')) if dictionary.get('indexingPolicy') else None
         is_active = dictionary.get('isActive')
         is_deleted = dictionary.get('isDeleted')
+        is_direct_archive_enabled = dictionary.get('isDirectArchiveEnabled')
+        is_direct_archive_native_format_enabled = dictionary.get('isDirectArchiveNativeFormatEnabled')
         is_paused = dictionary.get('isPaused')
         is_rpo_job = dictionary.get('isRpoJob')
         job_creation_time_usecs = dictionary.get('jobCreationTimeUsecs')
@@ -525,9 +556,12 @@ class BackupJobProto(object):
                    exclusion_ranges,
                    full_backup_job_policy,
                    full_backup_sla_time_mins,
+                   global_include_exclude,
                    indexing_policy,
                    is_active,
                    is_deleted,
+                   is_direct_archive_enabled,
+                   is_direct_archive_native_format_enabled,
                    is_paused,
                    is_rpo_job,
                    job_creation_time_usecs,
