@@ -6,10 +6,11 @@ import cohesity_management_sdk.models.cluster_audit_log_configuration
 import cohesity_management_sdk.models.eula_config
 import cohesity_management_sdk.models.filer_audit_log_configuration
 import cohesity_management_sdk.models.cluster_hardware_info
+import cohesity_management_sdk.models.license_state
 import cohesity_management_sdk.models.ntp_settings_config
+import cohesity_management_sdk.models.schema_info
 import cohesity_management_sdk.models.cluster_stats
 import cohesity_management_sdk.models.supported_config
-import cohesity_management_sdk.models.syslog_server
 
 class Cluster(object):
 
@@ -19,16 +20,14 @@ class Cluster(object):
 
     Attributes:
         apps_settings (AppsConfig): TODO: type description here.
+        assigned_racks_count (int): Specifies the number of racks in cluster
+            with at least one rack assigned.
         available_metadata_space (long|int): Information about storage
             available for metadata
         banner_enabled (bool): Specifies whether UI banner is enabled on the
             cluster or not. When banner is enabled, UI will make an additional
             API call to fetch the banner and show at the login page.
-        bonding_mode (BondingModeEnum): Specifies the bonding mode to use when
-            bonding NICs to this Cluster. 'KActiveBackup' indicates an
-            Active-backup policy bonding mode. 'K802_3ad' indicates an EEE
-            802.3ad Dynamic link aggregation bonding mode. 'KBalanceAlb'
-            indicates a Adaptive load balancing bonding mode.
+        chassis_count (int): Specifies the number of chassis in cluster.
         cluster_audit_log_config (ClusterAuditLogConfiguration): Specifies the
             settings of the Cluster audit log configuration.
         cluster_software_version (string): Specifies the current release of
@@ -82,6 +81,12 @@ class Cluster(object):
             the encryption keys are rotated every 77760000 seconds (30 days).
         eula_config (EulaConfig): Specifies the End User License Agreement
             (EULA) acceptance information.
+        fault_tolerance_level (FaultToleranceLevelEnum): Specifies the level
+            which 'MetadataFaultToleranceFactor' applies to. 'kNode' indicates
+            'MetadataFaultToleranceFactor' applies to Node level. 'kChassis'
+            indicates 'MetadataFaultToleranceFactor' applies to Chassis level.
+            'kRack' indicates 'MetadataFaultToleranceFactor' applies to Rack
+            level.
         filer_audit_log_config (FilerAuditLogConfiguration): Specifies the
             settings of the filer audit log configuration.
         fips_mode_enabled (bool): Specifies if the Cohesity Cluster should
@@ -96,6 +101,7 @@ class Cluster(object):
         id (long|int): Specifies the unique id of Cohesity Cluster.
         incarnation_id (long|int): Specifies the unique incarnation id of the
             Cohesity Cluster.
+        ip_preference (int): IP preference
         is_documentation_local (bool): Specifies what version of the
             documentation is used. If 'true', the version of documentation
             stored locally on the Cohesity Cluster is used. If 'false', the
@@ -105,16 +111,16 @@ class Cluster(object):
             version of Help.
         language_locale (string): Specifies the language and locale for this
             Cohesity Cluster.
-        license_server_claimed (bool): Speifies if cluster is claimed by
-            Helios or not.
+        license_state (LicenseState): Specifies the Licensing State
+            information.
+        local_auth_domain_name (string): Domain name for SMB local
+            authentication.
         local_groups_enabled (bool): Specifies whether to enable local groups
             on cluster. Once it is enabled, it cannot be disabled.
         metadata_fault_tolerance_factor (int): Specifies metadata fault
             tolerance setting for the cluster. This denotes the number of
             simultaneous failures[node] supported by metadata services like
             gandalf and scribe.
-        mtu (int): Specifies the Maxium Transmission Unit (MTU) in bytes of
-            the network.
         multi_tenancy_enabled (bool): Specifies if multi tenancy is enabled in
             the cluster. Authentication & Authorization will always use
             tenant_id, however, some UI elements may be disabled when multi
@@ -122,7 +128,10 @@ class Cluster(object):
         name (string): Specifies the name of the Cohesity Cluster.
         node_count (long|int): Specifies the number of Nodes in the Cohesity
             Cluster.
+        node_ips (string): IP addresses of nodes in the cluster
         ntp_settings (NtpSettingsConfig): TODO: type description here.
+        pcie_ssd_tier_rebalance_delay_secs (int): Specifies the rebalance
+            delay in seconds for cluster PcieSSD storage tier.
         proxy_vm_subnet (string): The subnet reserved for ProxyVM
         reverse_tunnel_enabled (bool): If 'true', Cohesity's Remote Tunnel is
             enabled. Cohesity can access the Cluster and provide remote
@@ -130,6 +139,8 @@ class Cluster(object):
         reverse_tunnel_end_time_msecs (long|int): ReverseTunnelEndTimeMsecs
             specifies the end time in milliseconds since epoch until when the
             reverse tunnel will stay enabled.
+        schema_info_list (list of SchemaInfo): Specifies the time series
+            schema info of the cluster.
         smb_ad_disabled (bool): Specifies if Active Directory should be
             disabled for authentication of SMB shares. If 'true', Active
             Directory is disabled.
@@ -140,8 +151,6 @@ class Cluster(object):
             options for the number of Nodes in the Cohesity Cluster. In
             addition, the minimum number of Nodes supported for this Cluster
             type is defined.
-        syslog_servers (list of SyslogServer): Array of Syslog Servers.
-            Specifies a list of Syslog servers to send audit logs to.
         target_software_version (string): Specifies the Cohesity release that
             this Cluster is being upgraded to if an upgrade operation is in
             progress.
@@ -161,9 +170,10 @@ class Cluster(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "apps_settings":'appsSettings',
+        "assigned_racks_count":'assignedRacksCount',
         "available_metadata_space":'availableMetadataSpace',
         "banner_enabled":'bannerEnabled',
-        "bonding_mode":'bondingMode',
+        "chassis_count":'chassisCount',
         "cluster_audit_log_config":'clusterAuditLogConfig',
         "cluster_software_version":'clusterSoftwareVersion',
         "cluster_type":'clusterType',
@@ -178,6 +188,7 @@ class Cluster(object):
         "encryption_enabled":'encryptionEnabled',
         "encryption_key_rotation_period_secs":'encryptionKeyRotationPeriodSecs',
         "eula_config":'eulaConfig',
+        "fault_tolerance_level":'faultToleranceLevel',
         "filer_audit_log_config":'filerAuditLogConfig',
         "fips_mode_enabled":'fipsModeEnabled',
         "gateway":'gateway',
@@ -185,24 +196,27 @@ class Cluster(object):
         "hardware_info":'hardwareInfo',
         "id":'id',
         "incarnation_id":'incarnationId',
+        "ip_preference":'ipPreference',
         "is_documentation_local":'isDocumentationLocal',
         "language_locale":'languageLocale',
-        "license_server_claimed":'licenseServerClaimed',
+        "license_state":'licenseState',
+        "local_auth_domain_name":'localAuthDomainName',
         "local_groups_enabled":'localGroupsEnabled',
         "metadata_fault_tolerance_factor":'metadataFaultToleranceFactor',
-        "mtu":'mtu',
         "multi_tenancy_enabled":'multiTenancyEnabled',
         "name":'name',
         "node_count":'nodeCount',
+        "node_ips":'nodeIps',
         "ntp_settings":'ntpSettings',
+        "pcie_ssd_tier_rebalance_delay_secs":'pcieSsdTierRebalanceDelaySecs',
         "proxy_vm_subnet":'proxyVMSubnet',
         "reverse_tunnel_enabled":'reverseTunnelEnabled',
         "reverse_tunnel_end_time_msecs":'reverseTunnelEndTimeMsecs',
+        "schema_info_list":'schemaInfoList',
         "smb_ad_disabled":'smbAdDisabled',
         "stats":'stats',
         "stig_mode":'stigMode',
         "supported_config":'supportedConfig',
-        "syslog_servers":'syslogServers',
         "target_software_version":'targetSoftwareVersion',
         "tenant_viewbox_sharing_enabled":'tenantViewboxSharingEnabled',
         "timezone":'timezone',
@@ -212,9 +226,10 @@ class Cluster(object):
 
     def __init__(self,
                  apps_settings=None,
+                 assigned_racks_count=None,
                  available_metadata_space=None,
                  banner_enabled=None,
-                 bonding_mode=None,
+                 chassis_count=None,
                  cluster_audit_log_config=None,
                  cluster_software_version=None,
                  cluster_type=None,
@@ -229,6 +244,7 @@ class Cluster(object):
                  encryption_enabled=None,
                  encryption_key_rotation_period_secs=None,
                  eula_config=None,
+                 fault_tolerance_level=None,
                  filer_audit_log_config=None,
                  fips_mode_enabled=None,
                  gateway=None,
@@ -236,24 +252,27 @@ class Cluster(object):
                  hardware_info=None,
                  id=None,
                  incarnation_id=None,
+                 ip_preference=None,
                  is_documentation_local=None,
                  language_locale=None,
-                 license_server_claimed=None,
+                 license_state=None,
+                 local_auth_domain_name=None,
                  local_groups_enabled=None,
                  metadata_fault_tolerance_factor=None,
-                 mtu=None,
                  multi_tenancy_enabled=None,
                  name=None,
                  node_count=None,
+                 node_ips=None,
                  ntp_settings=None,
+                 pcie_ssd_tier_rebalance_delay_secs=None,
                  proxy_vm_subnet=None,
                  reverse_tunnel_enabled=None,
                  reverse_tunnel_end_time_msecs=None,
+                 schema_info_list=None,
                  smb_ad_disabled=None,
                  stats=None,
                  stig_mode=None,
                  supported_config=None,
-                 syslog_servers=None,
                  target_software_version=None,
                  tenant_viewbox_sharing_enabled=None,
                  timezone=None,
@@ -263,9 +282,10 @@ class Cluster(object):
 
         # Initialize members of the class
         self.apps_settings = apps_settings
+        self.assigned_racks_count = assigned_racks_count
         self.available_metadata_space = available_metadata_space
         self.banner_enabled = banner_enabled
-        self.bonding_mode = bonding_mode
+        self.chassis_count = chassis_count
         self.cluster_audit_log_config = cluster_audit_log_config
         self.cluster_software_version = cluster_software_version
         self.cluster_type = cluster_type
@@ -280,6 +300,7 @@ class Cluster(object):
         self.encryption_enabled = encryption_enabled
         self.encryption_key_rotation_period_secs = encryption_key_rotation_period_secs
         self.eula_config = eula_config
+        self.fault_tolerance_level = fault_tolerance_level
         self.filer_audit_log_config = filer_audit_log_config
         self.fips_mode_enabled = fips_mode_enabled
         self.gateway = gateway
@@ -287,24 +308,27 @@ class Cluster(object):
         self.hardware_info = hardware_info
         self.id = id
         self.incarnation_id = incarnation_id
+        self.ip_preference = ip_preference
         self.is_documentation_local = is_documentation_local
         self.language_locale = language_locale
-        self.license_server_claimed = license_server_claimed
+        self.license_state = license_state
+        self.local_auth_domain_name = local_auth_domain_name
         self.local_groups_enabled = local_groups_enabled
         self.metadata_fault_tolerance_factor = metadata_fault_tolerance_factor
-        self.mtu = mtu
         self.multi_tenancy_enabled = multi_tenancy_enabled
         self.name = name
         self.node_count = node_count
+        self.node_ips = node_ips
         self.ntp_settings = ntp_settings
+        self.pcie_ssd_tier_rebalance_delay_secs = pcie_ssd_tier_rebalance_delay_secs
         self.proxy_vm_subnet = proxy_vm_subnet
         self.reverse_tunnel_enabled = reverse_tunnel_enabled
         self.reverse_tunnel_end_time_msecs = reverse_tunnel_end_time_msecs
+        self.schema_info_list = schema_info_list
         self.smb_ad_disabled = smb_ad_disabled
         self.stats = stats
         self.stig_mode = stig_mode
         self.supported_config = supported_config
-        self.syslog_servers = syslog_servers
         self.target_software_version = target_software_version
         self.tenant_viewbox_sharing_enabled = tenant_viewbox_sharing_enabled
         self.timezone = timezone
@@ -331,9 +355,10 @@ class Cluster(object):
 
         # Extract variables from the dictionary
         apps_settings = cohesity_management_sdk.models.apps_config.AppsConfig.from_dictionary(dictionary.get('appsSettings')) if dictionary.get('appsSettings') else None
+        assigned_racks_count = dictionary.get('assignedRacksCount', None)
         available_metadata_space = dictionary.get('availableMetadataSpace')
         banner_enabled = dictionary.get('bannerEnabled')
-        bonding_mode = dictionary.get('bondingMode')
+        chassis_count = dictionary.get('chassisCount')
         cluster_audit_log_config = cohesity_management_sdk.models.cluster_audit_log_configuration.ClusterAuditLogConfiguration.from_dictionary(dictionary.get('clusterAuditLogConfig')) if dictionary.get('clusterAuditLogConfig') else None
         cluster_software_version = dictionary.get('clusterSoftwareVersion')
         cluster_type = dictionary.get('clusterType')
@@ -348,6 +373,7 @@ class Cluster(object):
         encryption_enabled = dictionary.get('encryptionEnabled')
         encryption_key_rotation_period_secs = dictionary.get('encryptionKeyRotationPeriodSecs')
         eula_config = cohesity_management_sdk.models.eula_config.EulaConfig.from_dictionary(dictionary.get('eulaConfig')) if dictionary.get('eulaConfig') else None
+        fault_tolerance_level = dictionary.get('faultToleranceLevel')
         filer_audit_log_config = cohesity_management_sdk.models.filer_audit_log_configuration.FilerAuditLogConfiguration.from_dictionary(dictionary.get('filerAuditLogConfig')) if dictionary.get('filerAuditLogConfig') else None
         fips_mode_enabled = dictionary.get('fipsModeEnabled')
         gateway = dictionary.get('gateway')
@@ -355,28 +381,31 @@ class Cluster(object):
         hardware_info = cohesity_management_sdk.models.cluster_hardware_info.ClusterHardwareInfo.from_dictionary(dictionary.get('hardwareInfo')) if dictionary.get('hardwareInfo') else None
         id = dictionary.get('id')
         incarnation_id = dictionary.get('incarnationId')
+        ip_preference = dictionary.get('ipPreference')
         is_documentation_local = dictionary.get('isDocumentationLocal')
         language_locale = dictionary.get('languageLocale')
-        license_server_claimed = dictionary.get('licenseServerClaimed')
+        license_state = cohesity_management_sdk.models.license_state.LicenseState.from_dictionary(dictionary.get('licenseState')) if dictionary.get('licenseState') else None
+        local_auth_domain_name = dictionary.get('localAuthDomainName')
         local_groups_enabled = dictionary.get('localGroupsEnabled')
         metadata_fault_tolerance_factor = dictionary.get('metadataFaultToleranceFactor')
-        mtu = dictionary.get('mtu')
         multi_tenancy_enabled = dictionary.get('multiTenancyEnabled')
         name = dictionary.get('name')
         node_count = dictionary.get('nodeCount')
+        node_ips = dictionary.get('nodeIps')
         ntp_settings = cohesity_management_sdk.models.ntp_settings_config.NtpSettingsConfig.from_dictionary(dictionary.get('ntpSettings')) if dictionary.get('ntpSettings') else None
+        pcie_ssd_tier_rebalance_delay_secs = dictionary.get('pcieSsdTierRebalanceDelaySecs')
         proxy_vm_subnet = dictionary.get('proxyVMSubnet')
         reverse_tunnel_enabled = dictionary.get('reverseTunnelEnabled')
         reverse_tunnel_end_time_msecs = dictionary.get('reverseTunnelEndTimeMsecs')
+        schema_info_list = None
+        if dictionary.get('schemaInfoList') != None:
+            schema_info_list = list()
+            for structure in dictionary.get('schemaInfoList'):
+                schema_info_list.append(cohesity_management_sdk.models.schema_info.SchemaInfo.from_dictionary(structure))
         smb_ad_disabled = dictionary.get('smbAdDisabled')
         stats = cohesity_management_sdk.models.cluster_stats.ClusterStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
         stig_mode = dictionary.get('stigMode')
         supported_config = cohesity_management_sdk.models.supported_config.SupportedConfig.from_dictionary(dictionary.get('supportedConfig')) if dictionary.get('supportedConfig') else None
-        syslog_servers = None
-        if dictionary.get('syslogServers') != None:
-            syslog_servers = list()
-            for structure in dictionary.get('syslogServers'):
-                syslog_servers.append(cohesity_management_sdk.models.syslog_server.SyslogServer.from_dictionary(structure))
         target_software_version = dictionary.get('targetSoftwareVersion')
         tenant_viewbox_sharing_enabled = dictionary.get('tenantViewboxSharingEnabled')
         timezone = dictionary.get('timezone')
@@ -385,9 +414,10 @@ class Cluster(object):
 
         # Return an object of this model
         return cls(apps_settings,
+                   assigned_racks_count,
                    available_metadata_space,
                    banner_enabled,
-                   bonding_mode,
+                   chassis_count,
                    cluster_audit_log_config,
                    cluster_software_version,
                    cluster_type,
@@ -402,6 +432,7 @@ class Cluster(object):
                    encryption_enabled,
                    encryption_key_rotation_period_secs,
                    eula_config,
+                   fault_tolerance_level,
                    filer_audit_log_config,
                    fips_mode_enabled,
                    gateway,
@@ -409,24 +440,27 @@ class Cluster(object):
                    hardware_info,
                    id,
                    incarnation_id,
+                   ip_preference,
                    is_documentation_local,
                    language_locale,
-                   license_server_claimed,
+                   license_state,
+                   local_auth_domain_name,
                    local_groups_enabled,
                    metadata_fault_tolerance_factor,
-                   mtu,
                    multi_tenancy_enabled,
                    name,
                    node_count,
+                   node_ips,
                    ntp_settings,
+                   pcie_ssd_tier_rebalance_delay_secs,
                    proxy_vm_subnet,
                    reverse_tunnel_enabled,
                    reverse_tunnel_end_time_msecs,
+                   schema_info_list,
                    smb_ad_disabled,
                    stats,
                    stig_mode,
                    supported_config,
-                   syslog_servers,
                    target_software_version,
                    tenant_viewbox_sharing_enabled,
                    timezone,
