@@ -15,6 +15,7 @@ class EnvironmentListApplicationServersEnum(object):
         KPUPPETEER: TODO: type description here.
         KPHYSICAL: TODO: type description here.
         KPURE: TODO: type description here.
+        KNIMBLE: TODO: type description here.
         KAZURE: TODO: type description here.
         KNETAPP: TODO: type description here.
         KAGENT: TODO: type description here.
@@ -22,6 +23,7 @@ class EnvironmentListApplicationServersEnum(object):
         KACROPOLIS: TODO: type description here.
         KPHYSICALFILES: TODO: type description here.
         KISILON: TODO: type description here.
+        KGPFS: TODO: type description here.
         KKVM: TODO: type description here.
         KAWS: TODO: type description here.
         KEXCHANGE: TODO: type description here.
@@ -35,6 +37,10 @@ class EnvironmentListApplicationServersEnum(object):
         KHYPERFLEX: TODO: type description here.
         KGCPNATIVE: TODO: type description here.
         KAZURENATIVE: TODO: type description here.
+        KKUBERNETES: TODO: type description here.
+        KELASTIFILE: TODO: type description here.
+        KAD: TODO: type description here.
+        KRDSSNAPSHOTMANAGER: TODO: type description here.
 
     """
 
@@ -52,6 +58,8 @@ class EnvironmentListApplicationServersEnum(object):
 
     KPURE = 'kPure'
 
+    KNIMBLE = 'kNimble'
+
     KAZURE = 'kAzure'
 
     KNETAPP = 'kNetapp'
@@ -66,6 +74,8 @@ class EnvironmentListApplicationServersEnum(object):
 
     KISILON = 'kIsilon'
 
+    KGPFS = 'kGPFS'
+
     KKVM = 'kKVM'
 
     KAWS = 'kAWS'
@@ -92,3 +102,12 @@ class EnvironmentListApplicationServersEnum(object):
 
     KAZURENATIVE = 'kAzureNative'
 
+    KKUBERNETES = 'kKubernetes'
+
+    KELASTIFILE = 'kElastifile'
+
+    KAD = 'kAD'
+
+    KRDSSNAPSHOTMANAGER = 'kRDSSnapshotManager'
+
+
