@@ -10,12 +10,16 @@ class HostOsTypeEnum(object):
     'kWindows' indicates the Microsoft Windows operating system.
     'kAix' indicates the IBM AIX operating system.
     'kSolaris' indicates the Oracle Solaris operating system.
+    'kSapHana' indicates the Sap Hana database system developed by SAP SE.
+    'kOther' indicates the other types of operating system.
 
     Attributes:
         KLINUX: TODO: type description here.
         KWINDOWS: TODO: type description here.
         KAIX: TODO: type description here.
         KSOLARIS: TODO: type description here.
+        KSAPHANA: TODO: type description here.
+        KOTHER: TODO: type description here.
 
     """
 
@@ -27,3 +31,7 @@ class HostOsTypeEnum(object):
 
     KSOLARIS = 'kSolaris'
 
+    KSAPHANA = 'kSapHana'
+
+    KOTHER = 'kOther'
+
