@@ -11,11 +11,13 @@ class ObjectClassIdpPrincipalsAddParametersEnum(object):
     'kUser' specifies a user object class.
     'kGroup' specifies a group object class.
     'kComputer' specifies a computer object class.
+    'kWellKnownPrincipal' specifies a well known principal.
 
     Attributes:
         KUSER: TODO: type description here.
         KGROUP: TODO: type description here.
         KCOMPUTER: TODO: type description here.
+        KWELLKNOWNPRINCIPAL: TODO: type description here.
 
     """
 
@@ -25,3 +27,5 @@ class ObjectClassIdpPrincipalsAddParametersEnum(object):
 
     KCOMPUTER = 'kComputer'
 
+    KWELLKNOWNPRINCIPAL = 'kWellKnownPrincipal'
+
