@@ -22,9 +22,10 @@ class PhysicalSpecialParameters(object):
         file_paths (list of FilePathParameters): Array of File Paths to Back
             Up.  Specifies a list of directories or files to protect in a
             Physical Server.
-        metadata_file_path (string): Specifies metadata path on source. This
-            file contains absolute paths of files that needs to be backed up
-            on the same source.
+        skip_nested_volumes_vec (list of string): Specifies mounttypes of
+            nested volumes to be skipped.
+        uses_skip_nested_volumes_vec (bool): Specifies whether to use
+            SkipNestedVolumes vec to skip nested mounts.
         volume_guid (list of string): Array of Mounted Volumes to Back Up.
             Specifies the subset of mounted volumes to protect in a Physical
             Server. If not specified, all mounted volumes on a Physical Server
@@ -39,7 +40,8 @@ class PhysicalSpecialParameters(object):
         "application_parameters":'applicationParameters',
         "enable_system_backup":'enableSystemBackup',
         "file_paths":'filePaths',
-        "metadata_file_path":'metadataFilePath',
+        "skip_nested_volumes_vec":'skipNestedVolumesVec',
+        "uses_skip_nested_volumes_vec":'usesSkipNestedVolumesVec',
         "volume_guid":'volumeGuid',
         "windows_parameters":'windowsParameters'
     }
@@ -48,7 +50,8 @@ class PhysicalSpecialParameters(object):
                  application_parameters=None,
                  enable_system_backup=None,
                  file_paths=None,
-                 metadata_file_path=None,
+                 skip_nested_volumes_vec=None,
+                 uses_skip_nested_volumes_vec=None,
                  volume_guid=None,
                  windows_parameters=None):
         """Constructor for the PhysicalSpecialParameters class"""
@@ -57,7 +60,8 @@ class PhysicalSpecialParameters(object):
         self.application_parameters = application_parameters
         self.enable_system_backup = enable_system_backup
         self.file_paths = file_paths
-        self.metadata_file_path = metadata_file_path
+        self.skip_nested_volumes_vec = skip_nested_volumes_vec
+        self.uses_skip_nested_volumes_vec = uses_skip_nested_volumes_vec
         self.volume_guid = volume_guid
         self.windows_parameters = windows_parameters
 
@@ -87,7 +91,8 @@ class PhysicalSpecialParameters(object):
             file_paths = list()
             for structure in dictionary.get('filePaths'):
                 file_paths.append(cohesity_management_sdk.models.file_path_parameters.FilePathParameters.from_dictionary(structure))
-        metadata_file_path = dictionary.get('metadataFilePath')
+        skip_nested_volumes_vec = dictionary.get('skipNestedVolumesVec')
+        uses_skip_nested_volumes_vec = dictionary.get('usesSkipNestedVolumesVec')
         volume_guid = dictionary.get('volumeGuid')
         windows_parameters = cohesity_management_sdk.models.windows_host_snapshot_parameters.WindowsHostSnapshotParameters.from_dictionary(dictionary.get('windowsParameters')) if dictionary.get('windowsParameters') else None
 
@@ -95,7 +100,8 @@ class PhysicalSpecialParameters(object):
         return cls(application_parameters,
                    enable_system_backup,
                    file_paths,
-                   metadata_file_path,
+                   skip_nested_volumes_vec,
+                   uses_skip_nested_volumes_vec,
                    volume_guid,
                    windows_parameters)
 
