@@ -41,6 +41,8 @@ class ProtectionJob(object):
             certain scenarios.
         continue_on_quiesce_failure (bool): Whether to continue backing up on
             quiesce failure.
+        create_remote_view (bool): Specifies whether to create a remote view
+            name to use for view overwrite.
         creation_time_usecs (long|int): Specifies the time when the Protection
             Job was created.
         data_migration_policy (DataMigrationPolicy): Specifies settings for
@@ -64,28 +66,35 @@ class ProtectionJob(object):
             environment. 'kPuppeteer' indicates the Cohesity's Remote Adapter.
             'kPhysical' indicates the physical Protection Source environment.
             'kPure' indicates the Pure Storage Protection Source environment.
-            'kAzure' indicates the Microsoft's Azure Protection Source
-            environment. 'kNetapp' indicates the Netapp Protection Source
-            environment. 'kAgent' indicates the Agent Protection Source
-            environment. 'kGenericNas' indicates the Genreric Network Attached
+            'Nimble' indicates the Nimble Storage Protection Source
+            environment. 'kAzure' indicates the Microsoft's Azure Protection
+            Source environment. 'kNetapp' indicates the Netapp Protection
+            Source environment. 'kAgent' indicates the Agent Protection Source
+            environment. 'kGenericNas' indicates the Generic Network Attached
             Storage Protection Source environment. 'kAcropolis' indicates the
             Acropolis Protection Source environment. 'kPhsicalFiles' indicates
             the Physical Files Protection Source environment. 'kIsilon'
             indicates the Dell EMC's Isilon Protection Source environment.
-            'kKVM' indicates the KVM Protection Source environment. 'kAWS'
-            indicates the AWS Protection Source environment. 'kExchange'
-            indicates the Exchange Protection Source environment. 'kHyperVVSS'
-            indicates the HyperV VSS Protection Source environment. 'kOracle'
-            indicates the Oracle Protection Source environment. 'kGCP'
-            indicates the Google Cloud Platform Protection Source environment.
-            'kFlashBlade' indicates the Flash Blade Protection Source
-            environment. 'kAWSNative' indicates the AWS Native Protection
-            Source environment. 'kO365' indicates the Office 365 Protection
-            Source environment. 'kO365Outlook' indicates Office 365 outlook
+            'kGPFS' indicates IBM's GPFS Protection Source environment. 'kKVM'
+            indicates the KVM Protection Source environment. 'kAWS' indicates
+            the AWS Protection Source environment. 'kExchange' indicates the
+            Exchange Protection Source environment. 'kHyperVVSS' indicates the
+            HyperV VSS Protection Source environment. 'kOracle' indicates the
+            Oracle Protection Source environment. 'kGCP' indicates the Google
+            Cloud Platform Protection Source environment. 'kFlashBlade'
+            indicates the Flash Blade Protection Source environment.
+            'kAWSNative' indicates the AWS Native Protection Source
+            environment. 'kO365' indicates the Office 365 Protection Source
+            environment. 'kO365Outlook' indicates Office 365 outlook
             Protection Source environment. 'kHyperFlex' indicates the Hyper
             Flex Protection Source environment. 'kGCPNative' indicates the GCP
             Native Protection Source environment. 'kAzureNative' indicates the
-            Azure Native Protection Source environment.
+            Azure Native Protection Source environment. 'kKubernetes'
+            indicates a Kubernetes Protection Source environment.
+            'kElastifile' indicates Elastifile Protection Source environment.
+            'kAD' indicates Active Directory Protection Source environment.
+            'kRDSSnapshotManager' indicates AWS RDS Protection Source
+            environment.
         environment_parameters (EnvironmentTypeJobParameters): Specifies
             additional parameters that are common to all Protection Sources in
             a Protection Job created for a particular environment type.
@@ -151,6 +160,10 @@ class ProtectionJob(object):
         is_deleted (bool): Equals 'true' if the Protection Job was deleted but
             some Snapshots are still associated with this Job. If 'true', no
             new Job Runs are started by this Protection Job.
+        is_direct_archive_enabled (bool): Specifies if this is a direct
+            archive backup job.
+        is_native_format (bool): Specifies if native format should be used for
+            archiving, applicable for only direct archive jobs.
         is_paused (bool): Indicates if the Protection Job is paused, which
             means that no new Job Runs are started but any existing Job Runs
             continue to execute.
@@ -285,6 +298,7 @@ class ProtectionJob(object):
         "alerting_policy":'alertingPolicy',
         "cloud_parameters":'cloudParameters',
         "continue_on_quiesce_failure":'continueOnQuiesceFailure',
+        "create_remote_view":'createRemoteView',
         "creation_time_usecs":'creationTimeUsecs',
         "data_migration_policy":'dataMigrationPolicy',
         "dedup_disabled_source_ids":'dedupDisabledSourceIds',
@@ -302,6 +316,8 @@ class ProtectionJob(object):
         "indexing_policy":'indexingPolicy',
         "is_active":'isActive',
         "is_deleted":'isDeleted',
+        "is_direct_archive_enabled":'isDirectArchiveEnabled',
+        "is_native_format":'isNativeFormat',
         "is_paused":'isPaused',
         "last_run":'lastRun',
         "leverage_storage_snapshots":'leverageStorageSnapshots',
@@ -339,6 +355,7 @@ class ProtectionJob(object):
                  alerting_policy=None,
                  cloud_parameters=None,
                  continue_on_quiesce_failure=None,
+                 create_remote_view=None,
                  creation_time_usecs=None,
                  data_migration_policy=None,
                  dedup_disabled_source_ids=None,
@@ -356,6 +373,8 @@ class ProtectionJob(object):
                  indexing_policy=None,
                  is_active=None,
                  is_deleted=None,
+                 is_direct_archive_enabled=None,
+                 is_native_format=None,
                  is_paused=None,
                  last_run=None,
                  leverage_storage_snapshots=None,
@@ -390,6 +409,7 @@ class ProtectionJob(object):
         self.alerting_policy = alerting_policy
         self.cloud_parameters = cloud_parameters
         self.continue_on_quiesce_failure = continue_on_quiesce_failure
+        self.create_remote_view = create_remote_view
         self.creation_time_usecs = creation_time_usecs
         self.data_migration_policy = data_migration_policy
         self.dedup_disabled_source_ids = dedup_disabled_source_ids
@@ -407,6 +427,8 @@ class ProtectionJob(object):
         self.indexing_policy = indexing_policy
         self.is_active = is_active
         self.is_deleted = is_deleted
+        self.is_direct_archive_enabled = is_direct_archive_enabled
+        self.is_native_format = is_native_format
         self.is_paused = is_paused
         self.last_run = last_run
         self.leverage_storage_snapshots = leverage_storage_snapshots
@@ -464,6 +486,7 @@ class ProtectionJob(object):
         alerting_policy = dictionary.get('alertingPolicy')
         cloud_parameters = cohesity_management_sdk.models.cloud_parameters.CloudParameters.from_dictionary(dictionary.get('cloudParameters')) if dictionary.get('cloudParameters') else None
         continue_on_quiesce_failure = dictionary.get('continueOnQuiesceFailure')
+        create_remote_view = dictionary.get('createRemoteView')
         creation_time_usecs = dictionary.get('creationTimeUsecs')
         data_migration_policy = cohesity_management_sdk.models.data_migration_policy.DataMigrationPolicy.from_dictionary(dictionary.get('dataMigrationPolicy')) if dictionary.get('dataMigrationPolicy') else None
         dedup_disabled_source_ids = dictionary.get('dedupDisabledSourceIds')
@@ -481,6 +504,8 @@ class ProtectionJob(object):
         indexing_policy = cohesity_management_sdk.models.indexing_policy.IndexingPolicy.from_dictionary(dictionary.get('indexingPolicy')) if dictionary.get('indexingPolicy') else None
         is_active = dictionary.get('isActive')
         is_deleted = dictionary.get('isDeleted')
+        is_direct_archive_enabled = dictionary.get('isDirectArchiveEnabled')
+        is_native_format = dictionary.get('isNativeFormat')
         is_paused = dictionary.get('isPaused')
         last_run = cohesity_management_sdk.models.protection_run_instance.ProtectionRunInstance.from_dictionary(dictionary.get('lastRun')) if dictionary.get('lastRun') else None
         leverage_storage_snapshots = dictionary.get('leverageStorageSnapshots')
@@ -521,6 +546,7 @@ class ProtectionJob(object):
                    alerting_policy,
                    cloud_parameters,
                    continue_on_quiesce_failure,
+                   create_remote_view,
                    creation_time_usecs,
                    data_migration_policy,
                    dedup_disabled_source_ids,
@@ -538,6 +564,8 @@ class ProtectionJob(object):
                    indexing_policy,
                    is_active,
                    is_deleted,
+                   is_direct_archive_enabled,
+                   is_native_format,
                    is_paused,
                    last_run,
                    leverage_storage_snapshots,
