@@ -21,6 +21,9 @@ class ProtectionPolicyRequest(object):
             are not started. If a Job Run has been scheduled but not yet
             executed and the blackout period starts, the behavior depends on
             the policy field AbortInBlackoutPeriod.
+        cdp_scheduling_policy (SchedulingPolicy): Specifies the CDP backup
+            schedule of a Protection Job and how long log files captured by
+            this schedule are retained on the Cohesity Cluster.
         cloud_deploy_policies (list of SnapshotCloudCopyPolicy): Array of
             Cloud Deploy Policies.  Specifies settings for copying Snapshots
             to Cloud. CloudDeploy target where backup snapshots may be
@@ -51,6 +54,9 @@ class ProtectionPolicyRequest(object):
         name (string): Specifies the name of the Protection Policy.
         num_linked_policies (long|int): Species the number of policies linked
             to a global policy.
+        parent_policy_id (string): Specifies the parent global policy Id. This
+            must be specified when creating a policy from global policy
+            template.
         retries (int): Specifies the number of times to retry capturing
             Snapshots before the Job Run fails.
         retry_interval_mins (int): Specifies the number of minutes before
@@ -97,6 +103,7 @@ class ProtectionPolicyRequest(object):
     # Create a mapping from Model property names to API property names
     _names = {
         "blackout_periods":'blackoutPeriods',
+        "cdp_scheduling_policy":'cdpSchedulingPolicy',
         "cloud_deploy_policies":'cloudDeployPolicies',
         "days_to_keep":'daysToKeep',
         "days_to_keep_log":'daysToKeepLog',
@@ -108,6 +115,7 @@ class ProtectionPolicyRequest(object):
         "log_scheduling_policy":'logSchedulingPolicy',
         "name":'name',
         "num_linked_policies":'numLinkedPolicies',
+        "parent_policy_id":'parentPolicyId',
         "retries":'retries',
         "retry_interval_mins":'retryIntervalMins',
         "rpo_policy_settings":'rpoPolicySettings',
@@ -121,6 +129,7 @@ class ProtectionPolicyRequest(object):
 
     def __init__(self,
                  blackout_periods=None,
+                 cdp_scheduling_policy=None,
                  cloud_deploy_policies=None,
                  days_to_keep=None,
                  days_to_keep_log=None,
@@ -132,6 +141,7 @@ class ProtectionPolicyRequest(object):
                  log_scheduling_policy=None,
                  name=None,
                  num_linked_policies=None,
+                 parent_policy_id=None,
                  retries=None,
                  retry_interval_mins=None,
                  rpo_policy_settings=None,
@@ -145,6 +155,7 @@ class ProtectionPolicyRequest(object):
 
         # Initialize members of the class
         self.blackout_periods = blackout_periods
+        self.cdp_scheduling_policy = cdp_scheduling_policy
         self.cloud_deploy_policies = cloud_deploy_policies
         self.days_to_keep = days_to_keep
         self.days_to_keep_log = days_to_keep_log
@@ -156,6 +167,7 @@ class ProtectionPolicyRequest(object):
         self.log_scheduling_policy = log_scheduling_policy
         self.name = name
         self.num_linked_policies = num_linked_policies
+        self.parent_policy_id = parent_policy_id
         self.retries = retries
         self.retry_interval_mins = retry_interval_mins
         self.rpo_policy_settings = rpo_policy_settings
@@ -190,6 +202,7 @@ class ProtectionPolicyRequest(object):
             blackout_periods = list()
             for structure in dictionary.get('blackoutPeriods'):
                 blackout_periods.append(cohesity_management_sdk.models.blackout_period.BlackoutPeriod.from_dictionary(structure))
+        cdp_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('cdpSchedulingPolicy')) if dictionary.get('cdpSchedulingPolicy') else None
         cloud_deploy_policies = None
         if dictionary.get('cloudDeployPolicies') != None:
             cloud_deploy_policies = list()
@@ -209,6 +222,7 @@ class ProtectionPolicyRequest(object):
         log_scheduling_policy = cohesity_management_sdk.models.scheduling_policy.SchedulingPolicy.from_dictionary(dictionary.get('logSchedulingPolicy')) if dictionary.get('logSchedulingPolicy') else None
         name = dictionary.get('name')
         num_linked_policies = dictionary.get('numLinkedPolicies')
+        parent_policy_id = dictionary.get('parentPolicyId')
         retries = dictionary.get('retries')
         retry_interval_mins = dictionary.get('retryIntervalMins')
         rpo_policy_settings = cohesity_management_sdk.models.rpo_policy_settings.RpoPolicySettings.from_dictionary(dictionary.get('rpoPolicySettings')) if dictionary.get('rpoPolicySettings') else None
@@ -229,6 +243,7 @@ class ProtectionPolicyRequest(object):
 
         # Return an object of this model
         return cls(blackout_periods,
+                   cdp_scheduling_policy,
                    cloud_deploy_policies,
                    days_to_keep,
                    days_to_keep_log,
@@ -240,6 +255,7 @@ class ProtectionPolicyRequest(object):
                    log_scheduling_policy,
                    name,
                    num_linked_policies,
+                   parent_policy_id,
                    retries,
                    retry_interval_mins,
                    rpo_policy_settings,
