@@ -20,29 +20,35 @@ class ProtectionSummaryByEnv(object):
             the View Protection Source environment. 'kPuppeteer' indicates the
             Cohesity's Remote Adapter. 'kPhysical' indicates the physical
             Protection Source environment. 'kPure' indicates the Pure Storage
-            Protection Source environment. 'kAzure' indicates the Microsoft's
-            Azure Protection Source environment. 'kNetapp' indicates the
-            Netapp Protection Source environment. 'kAgent' indicates the Agent
-            Protection Source environment. 'kGenericNas' indicates the
-            Genreric Network Attached Storage Protection Source environment.
-            'kAcropolis' indicates the Acropolis Protection Source
-            environment. 'kPhsicalFiles' indicates the Physical Files
+            Protection Source environment. 'Nimble' indicates the Nimble
+            Storage Protection Source environment. 'kAzure' indicates the
+            Microsoft's Azure Protection Source environment. 'kNetapp'
+            indicates the Netapp Protection Source environment. 'kAgent'
+            indicates the Agent Protection Source environment. 'kGenericNas'
+            indicates the Generic Network Attached Storage Protection Source
+            environment. 'kAcropolis' indicates the Acropolis Protection
+            Source environment. 'kPhsicalFiles' indicates the Physical Files
             Protection Source environment. 'kIsilon' indicates the Dell EMC's
-            Isilon Protection Source environment. 'kKVM' indicates the KVM
-            Protection Source environment. 'kAWS' indicates the AWS Protection
-            Source environment. 'kExchange' indicates the Exchange Protection
-            Source environment. 'kHyperVVSS' indicates the HyperV VSS
-            Protection Source environment. 'kOracle' indicates the Oracle
-            Protection Source environment. 'kGCP' indicates the Google Cloud
-            Platform Protection Source environment. 'kFlashBlade' indicates
-            the Flash Blade Protection Source environment. 'kAWSNative'
-            indicates the AWS Native Protection Source environment. 'kO365'
-            indicates the Office 365 Protection Source environment.
-            'kO365Outlook' indicates Office 365 outlook Protection Source
-            environment. 'kHyperFlex' indicates the Hyper Flex Protection
-            Source environment. 'kGCPNative' indicates the GCP Native
-            Protection Source environment. 'kAzureNative' indicates the Azure
-            Native Protection Source environment.
+            Isilon Protection Source environment. 'kGPFS' indicates IBM's GPFS
+            Protection Source environment. 'kKVM' indicates the KVM Protection
+            Source environment. 'kAWS' indicates the AWS Protection Source
+            environment. 'kExchange' indicates the Exchange Protection Source
+            environment. 'kHyperVVSS' indicates the HyperV VSS Protection
+            Source environment. 'kOracle' indicates the Oracle Protection
+            Source environment. 'kGCP' indicates the Google Cloud Platform
+            Protection Source environment. 'kFlashBlade' indicates the Flash
+            Blade Protection Source environment. 'kAWSNative' indicates the
+            AWS Native Protection Source environment. 'kO365' indicates the
+            Office 365 Protection Source environment. 'kO365Outlook' indicates
+            Office 365 outlook Protection Source environment. 'kHyperFlex'
+            indicates the Hyper Flex Protection Source environment.
+            'kGCPNative' indicates the GCP Native Protection Source
+            environment. 'kAzureNative' indicates the Azure Native Protection
+            Source environment. 'kKubernetes' indicates a Kubernetes
+            Protection Source environment. 'kElastifile' indicates Elastifile
+            Protection Source environment. 'kAD' indicates Active Directory
+            Protection Source environment. 'kRDSSnapshotManager' indicates AWS
+            RDS Protection Source environment.
         protected_count (long|int): Specifies the number of objects that are
             protected under the given entity.
         protected_size (long|int): Specifies the total size of the protected
