@@ -19,6 +19,10 @@ class TierTypeEnum(object):
     'kAmazonS3IntelligentTiering' indicates a tier type of Amazon properties
     for
     data with unknown or changing access patterns.
+    'kAmazonS3GlacierDeepArchive' indicates a tier type of Amazon properties
+    for
+    data that provides secure, durable object storage for long-term data
+    retention and digital preservation.
 
     Attributes:
         KAMAZONS3STANDARD: TODO: type description here.
@@ -26,6 +30,7 @@ class TierTypeEnum(object):
         KAMAZONGLACIER: TODO: type description here.
         KAMAZONS3ONEZONEIA: TODO: type description here.
         KAMAZONS3INTELLIGENTTIERING: TODO: type description here.
+        KAMAZONS3GLACIERDEEPARCHIVE: TODO: type description here.
 
     """
 
@@ -39,3 +44,5 @@ class TierTypeEnum(object):
 
     KAMAZONS3INTELLIGENTTIERING = 'kAmazonS3IntelligentTiering'
 
+    KAMAZONS3GLACIERDEEPARCHIVE = 'kAmazonS3GlacierDeepArchive'
+
