@@ -15,15 +15,11 @@ class UpdateClusterParams(object):
     Cohesity Cluster.
 
     Attributes:
-        apps_settings (AppsConfig): TODO: type description here.
+        apps_settings (AppsConfig): Specifies the Athena apps mode for the
+            cluster.
         banner_enabled (bool): Specifies whether UI banner is enabled on the
             cluster or not. When banner is enabled, UI will make an additional
             API call to fetch the banner and show at the login page.
-        bonding_mode (BondingModeEnum): Specifies the bonding mode to use when
-            bonding NICs to this Cluster. 'KActiveBackup' indicates an
-            Active-backup policy bonding mode. 'K802_3ad' indicates an EEE
-            802.3ad Dynamic link aggregation bonding mode. 'KBalanceAlb'
-            indicates a Adaptive load balancing bonding mode.
         cluster_audit_log_config (ClusterAuditLogConfiguration): Specifies the
             settings of the Cluster audit log configuration.
         dns_server_ips (list of string): Array of IP Addresses of DNS Servers.
@@ -42,6 +38,15 @@ class UpdateClusterParams(object):
         encryption_key_rotation_period_secs (long|int): Specifies the period
             of time (in seconds) when encryption keys are rotated. By default,
             the encryption keys are rotated every 77760000 seconds (30 days).
+        fault_tolerance_level (UpdateClusterParamsFaultToleranceLevelEnum):
+            Specifies the level which 'MetadataFaultToleranceFactor' applies
+            to.
+            'kNode' indicates 'MetadataFaultToleranceFactor' applies to Node
+            level.
+            'kChassis' indicates 'MetadataFaultToleranceFactor' applies to
+            Chassis level.
+            'kRack' indicates 'MetadataFaultToleranceFactor' applies to Rack
+            level.
         filer_audit_log_config (FilerAuditLogConfiguration): Specifies the
             settings of the filer audit log configuration.
         gateway (string): Specifies the gateway IP address.
@@ -56,22 +61,23 @@ class UpdateClusterParams(object):
             version of Help.
         language_locale (string): Specifies the language and locale for this
             Cohesity Cluster.
-        license_server_claimed (bool): Speifies if cluster is claimed by
-            Helios or not.
+        local_auth_domain_name (string): Domain name for SMB local
+            authentication.
         local_groups_enabled (bool): Specifies whether to enable local groups
             on cluster. Once it is enabled, it cannot be disabled.
         metadata_fault_tolerance_factor (int): Specifies metadata fault
             tolerance setting for the cluster. This denotes the number of
             simultaneous failures[node] supported by metadata services like
             gandalf and scribe.
-        mtu (int): Specifies the Maxium Transmission Unit (MTU) in bytes of
-            the network.
         multi_tenancy_enabled (bool): Specifies if multi tenancy is enabled in
             the cluster. Authentication & Authorization will always use
             tenant_id, however, some UI elements may be disabled when multi
             tenancy is disabled.
         name (string): Specifies the name of the Cohesity Cluster.
-        ntp_settings (NtpSettingsConfig): TODO: type description here.
+        ntp_settings (NtpSettingsConfig): Specifies if the ntp/master slave
+            scheme should be disabled for this cluster.
+        pcie_ssd_tier_rebalance_delay_secs (int): Specifies the rebalance
+            delay in seconds for cluster PcieSSD storage tier.
         reverse_tunnel_enabled (bool): If 'true', Cohesity's Remote Tunnel is
             enabled. Cohesity can access the Cluster and provide remote
             assistance via a Remote Tunnel.
@@ -98,25 +104,25 @@ class UpdateClusterParams(object):
     _names = {
         "apps_settings":'appsSettings',
         "banner_enabled":'bannerEnabled',
-        "bonding_mode":'bondingMode',
         "cluster_audit_log_config":'clusterAuditLogConfig',
         "dns_server_ips":'dnsServerIps',
         "domain_names":'domainNames',
         "enable_active_monitoring":'enableActiveMonitoring',
         "enable_upgrade_pkg_polling":'enableUpgradePkgPolling',
         "encryption_key_rotation_period_secs":'encryptionKeyRotationPeriodSecs',
+        "fault_tolerance_level":'faultToleranceLevel',
         "filer_audit_log_config":'filerAuditLogConfig',
         "gateway":'gateway',
         "google_analytics_enabled":'googleAnalyticsEnabled',
         "is_documentation_local":'isDocumentationLocal',
         "language_locale":'languageLocale',
-        "license_server_claimed":'licenseServerClaimed',
+        "local_auth_domain_name":'localAuthDomainName',
         "local_groups_enabled":'localGroupsEnabled',
         "metadata_fault_tolerance_factor":'metadataFaultToleranceFactor',
-        "mtu":'mtu',
         "multi_tenancy_enabled":'multiTenancyEnabled',
         "name":'name',
         "ntp_settings":'ntpSettings',
+        "pcie_ssd_tier_rebalance_delay_secs":'pcieSsdTierRebalanceDelaySecs',
         "reverse_tunnel_enabled":'reverseTunnelEnabled',
         "reverse_tunnel_end_time_msecs":'reverseTunnelEndTimeMsecs',
         "smb_ad_disabled":'smbAdDisabled',
@@ -130,25 +136,25 @@ class UpdateClusterParams(object):
     def __init__(self,
                  apps_settings=None,
                  banner_enabled=None,
-                 bonding_mode=None,
                  cluster_audit_log_config=None,
                  dns_server_ips=None,
                  domain_names=None,
                  enable_active_monitoring=None,
                  enable_upgrade_pkg_polling=None,
                  encryption_key_rotation_period_secs=None,
+                 fault_tolerance_level=None,
                  filer_audit_log_config=None,
                  gateway=None,
                  google_analytics_enabled=None,
                  is_documentation_local=None,
                  language_locale=None,
-                 license_server_claimed=None,
+                 local_auth_domain_name=None,
                  local_groups_enabled=None,
                  metadata_fault_tolerance_factor=None,
-                 mtu=None,
                  multi_tenancy_enabled=None,
                  name=None,
                  ntp_settings=None,
+                 pcie_ssd_tier_rebalance_delay_secs=None,
                  reverse_tunnel_enabled=None,
                  reverse_tunnel_end_time_msecs=None,
                  smb_ad_disabled=None,
@@ -162,25 +168,25 @@ class UpdateClusterParams(object):
         # Initialize members of the class
         self.apps_settings = apps_settings
         self.banner_enabled = banner_enabled
-        self.bonding_mode = bonding_mode
         self.cluster_audit_log_config = cluster_audit_log_config
         self.dns_server_ips = dns_server_ips
         self.domain_names = domain_names
         self.enable_active_monitoring = enable_active_monitoring
         self.enable_upgrade_pkg_polling = enable_upgrade_pkg_polling
         self.encryption_key_rotation_period_secs = encryption_key_rotation_period_secs
+        self.fault_tolerance_level = fault_tolerance_level
         self.filer_audit_log_config = filer_audit_log_config
         self.gateway = gateway
         self.google_analytics_enabled = google_analytics_enabled
         self.is_documentation_local = is_documentation_local
         self.language_locale = language_locale
-        self.license_server_claimed = license_server_claimed
+        self.local_auth_domain_name = local_auth_domain_name
         self.local_groups_enabled = local_groups_enabled
         self.metadata_fault_tolerance_factor = metadata_fault_tolerance_factor
-        self.mtu = mtu
         self.multi_tenancy_enabled = multi_tenancy_enabled
         self.name = name
         self.ntp_settings = ntp_settings
+        self.pcie_ssd_tier_rebalance_delay_secs = pcie_ssd_tier_rebalance_delay_secs
         self.reverse_tunnel_enabled = reverse_tunnel_enabled
         self.reverse_tunnel_end_time_msecs = reverse_tunnel_end_time_msecs
         self.smb_ad_disabled = smb_ad_disabled
@@ -211,25 +217,25 @@ class UpdateClusterParams(object):
         # Extract variables from the dictionary
         apps_settings = cohesity_management_sdk.models.apps_config.AppsConfig.from_dictionary(dictionary.get('appsSettings')) if dictionary.get('appsSettings') else None
         banner_enabled = dictionary.get('bannerEnabled')
-        bonding_mode = dictionary.get('bondingMode')
         cluster_audit_log_config = cohesity_management_sdk.models.cluster_audit_log_configuration.ClusterAuditLogConfiguration.from_dictionary(dictionary.get('clusterAuditLogConfig')) if dictionary.get('clusterAuditLogConfig') else None
         dns_server_ips = dictionary.get('dnsServerIps')
         domain_names = dictionary.get('domainNames')
         enable_active_monitoring = dictionary.get('enableActiveMonitoring')
         enable_upgrade_pkg_polling = dictionary.get('enableUpgradePkgPolling')
         encryption_key_rotation_period_secs = dictionary.get('encryptionKeyRotationPeriodSecs')
+        fault_tolerance_level = dictionary.get('faultToleranceLevel')
         filer_audit_log_config = cohesity_management_sdk.models.filer_audit_log_configuration.FilerAuditLogConfiguration.from_dictionary(dictionary.get('filerAuditLogConfig')) if dictionary.get('filerAuditLogConfig') else None
         gateway = dictionary.get('gateway')
         google_analytics_enabled = dictionary.get('googleAnalyticsEnabled')
         is_documentation_local = dictionary.get('isDocumentationLocal')
         language_locale = dictionary.get('languageLocale')
-        license_server_claimed = dictionary.get('licenseServerClaimed')
+        local_auth_domain_name = dictionary.get('localAuthDomainName')
         local_groups_enabled = dictionary.get('localGroupsEnabled')
         metadata_fault_tolerance_factor = dictionary.get('metadataFaultToleranceFactor')
-        mtu = dictionary.get('mtu')
         multi_tenancy_enabled = dictionary.get('multiTenancyEnabled')
         name = dictionary.get('name')
         ntp_settings = cohesity_management_sdk.models.ntp_settings_config.NtpSettingsConfig.from_dictionary(dictionary.get('ntpSettings')) if dictionary.get('ntpSettings') else None
+        pcie_ssd_tier_rebalance_delay_secs = dictionary.get('pcieSsdTierRebalanceDelaySecs')
         reverse_tunnel_enabled = dictionary.get('reverseTunnelEnabled')
         reverse_tunnel_end_time_msecs = dictionary.get('reverseTunnelEndTimeMsecs')
         smb_ad_disabled = dictionary.get('smbAdDisabled')
@@ -246,25 +252,25 @@ class UpdateClusterParams(object):
         # Return an object of this model
         return cls(apps_settings,
                    banner_enabled,
-                   bonding_mode,
                    cluster_audit_log_config,
                    dns_server_ips,
                    domain_names,
                    enable_active_monitoring,
                    enable_upgrade_pkg_polling,
                    encryption_key_rotation_period_secs,
+                   fault_tolerance_level,
                    filer_audit_log_config,
                    gateway,
                    google_analytics_enabled,
                    is_documentation_local,
                    language_locale,
-                   license_server_claimed,
+                   local_auth_domain_name,
                    local_groups_enabled,
                    metadata_fault_tolerance_factor,
-                   mtu,
                    multi_tenancy_enabled,
                    name,
                    ntp_settings,
+                   pcie_ssd_tier_rebalance_delay_secs,
                    reverse_tunnel_enabled,
                    reverse_tunnel_end_time_msecs,
                    smb_ad_disabled,
