@@ -1,12 +1,15 @@
 # -*- coding: utf-8 -*-
 # Copyright 2020 Cohesity Inc.
 
-import cohesity_management_sdk.models.view_alias_info
+import cohesity_management_sdk.models.view_alias
 import cohesity_management_sdk.models.antivirus_scan_config
 import cohesity_management_sdk.models.file_extension_filter
 import cohesity_management_sdk.models.file_level_data_lock_config
 import cohesity_management_sdk.models.quota_policy
+import cohesity_management_sdk.models.nfs_squash
+import cohesity_management_sdk.models.nfs_root_permissions
 import cohesity_management_sdk.models.qo_s
+import cohesity_management_sdk.models.smb_permission
 import cohesity_management_sdk.models.smb_permissions_info
 import cohesity_management_sdk.models.view_stats
 import cohesity_management_sdk.models.storage_policy_override
@@ -26,7 +29,7 @@ class View(object):
         access_sids (list of string): Array of Security Identifiers (SIDs)
             Specifies the list of security identifiers (SIDs) for the
             restricted Principals who have access to this View.
-        aliases (list of ViewAliasInfo): Aliases created for the view. A view
+        aliases (list of ViewAlias): Aliases created for the view. A view
             alias allows a directory path inside a view to be mounted using
             the alias name.
         all_smb_mount_paths (list of string): Array of SMB Paths.  Specifies
@@ -51,13 +54,21 @@ class View(object):
             time.
         description (string): Specifies an optional text description about the
             View.
+        enable_fast_durable_handle (bool): Specifies whether fast durable
+            handle is enabled. If enabled, view open handle will be kept in
+            memory, which results in a higher performance. But the handles
+            cannot be recovered if node or service crashes.
         enable_filer_audit_logging (bool): Specifies if Filer Audit Logging is
             enabled for this view.
+        enable_live_indexing (bool): Specifies whether to enable live indexing
+            for the view.
         enable_mixed_mode_permissions (bool): If set, mixed mode (NFS and SMB)
             access is enabled for this view. This field is deprecated. Use the
             field SecurityMode. deprecated: true
         enable_nfs_view_discovery (bool): If set, it enables discovery of view
             for NFS.
+        enable_offline_caching (bool): Specifies whether to enable offline
+            file caching of the view.
         enable_smb_access_based_enumeration (bool): Specifies if access-based
             enumeration should be enabled. If 'true', only files and folders
             that the user has permissions to access are visible on the SMB
@@ -66,14 +77,17 @@ class View(object):
             View. If set, it enables the SMB encryption for the View.
             Encryption is supported only by SMB 3.x dialects. Dialects that do
             not support would still access data in unencrypted format.
+        enable_smb_oplock (bool): Specifies whether SMB opportunistic lock is
+            enabled.
         enable_smb_view_discovery (bool): If set, it enables discovery of view
             for SMB.
         enforce_smb_encryption (bool): Specifies the SMB encryption for all
             the sessions for the View. If set, encryption is enforced for all
             the sessions for the View. When enabled all future and existing
             unencrypted sessions are disallowed.
-        file_extension_filter (FileExtensionFilter): TODO: type description
-            here.
+        file_extension_filter (FileExtensionFilter): Optional filtering
+            criteria that should be satisfied by all the files created in
+            this view. It does not affect existing files.
         file_lock_config (FileLevelDataLockConfig): Specifies a config to lock
             files in a view - to protect from malicious or an accidental
             attempt to delete or modify the files in this view.
@@ -95,8 +109,14 @@ class View(object):
         logical_usage_bytes (long|int): LogicalUsageBytes is the logical usage
             in bytes for the view.
         name (string): Specifies the name of the View.
+        nfs_all_squash (NfsSquash): Specifies the NFS all squash config.
         nfs_mount_path (string): Specifies the path for mounting this View as
             an NFS share.
+        nfs_root_permissions (NfsRootPermissions): Specifies the config of NFS
+            root permission of a view file system.
+        nfs_root_squash (NfsSquash): Specifies the NFS root squash config.
+        override_global_whitelist (bool): Specifies whether view level client
+            subnet whitelist overrides cluster and global setting.
         protocol_access (ProtocolAccessEnum): Specifies the supported
             Protocols for the View. 'kAll' enables protocol access to all
             three views: NFS, SMB and S3. 'kNFSOnly' enables protocol access
@@ -106,11 +126,17 @@ class View(object):
             View.
         s_3_access_path (string): Specifies the path to access this View as an
             S3 share.
+        s_3_key_mapping_config (S3KeyMappingConfigEnum): Specifies the S3 key
+            mapping config of the view. This parameter can only be set during
+            create and cannot be changed. Configuration of S3 key mapping.
+            Specifies the type of S3 key mapping config.
         security_mode (SecurityModeEnum): Specifies the security mode used for
             this view. Currently we support the following modes: Native,
             Unified and NTFS style. 'kNativeMode' indicates a native security
             mode. 'kUnifiedMode' indicates a unified security mode.
             'kNtfsMode' indicates a NTFS style security mode.
+        share_permissions (list of SmbPermission): Specifies a list of share
+            level permissions.
         smb_mount_path (string): Specifies the main path for mounting this
             View as an SMB share.
         smb_permissions_info (SmbPermissionsInfo): Specifies information about
@@ -123,6 +149,10 @@ class View(object):
             of Subnets with IP addresses that have permissions to access the
             View. (Overrides the Subnets specified at the global Cohesity
             Cluster level.)
+        swift_project_domain (string): Specifies the Keystone project domain.
+        swift_project_name (string): Specifies the Keystone project name.
+        swift_user_domain (string): Specifies the Keystone user domain.
+        swift_username (string): Specifies the Keystone username.
         tenant_id (string): Optional tenant id who has access to this View.
         view_box_id (long|int): Specifies the id of the Storage Domain (View
             Box) where the View is stored.
@@ -130,9 +160,6 @@ class View(object):
             Box) where the View is stored.
         view_id (long|int): Specifies an id of the View assigned by the
             Cohesity Cluster.
-        view_lock_enabled (bool): Specifies whether view lock is enabled. If
-            enabled the view cannot be modified or deleted until unlock. By
-            default it is disabled.
         view_protection (ViewProtection): Specifies information about the
             Protection Jobs that are protecting the View.
 
@@ -149,11 +176,15 @@ class View(object):
         "create_time_msecs":'createTimeMsecs',
         "data_lock_expiry_usecs":'dataLockExpiryUsecs',
         "description":'description',
+        "enable_fast_durable_handle":'enableFastDurableHandle',
         "enable_filer_audit_logging":'enableFilerAuditLogging',
+        "enable_live_indexing":'enableLiveIndexing',
         "enable_mixed_mode_permissions":'enableMixedModePermissions',
         "enable_nfs_view_discovery":'enableNfsViewDiscovery',
+        "enable_offline_caching":'enableOfflineCaching',
         "enable_smb_access_based_enumeration":'enableSmbAccessBasedEnumeration',
         "enable_smb_encryption":'enableSmbEncryption',
+        "enable_smb_oplock":'enableSmbOplock',
         "enable_smb_view_discovery":'enableSmbViewDiscovery',
         "enforce_smb_encryption":'enforceSmbEncryption',
         "file_extension_filter":'fileExtensionFilter',
@@ -162,21 +193,30 @@ class View(object):
         "logical_quota":'logicalQuota',
         "logical_usage_bytes":'logicalUsageBytes',
         "name":'name',
+        "nfs_all_squash":'nfsAllSquash',
         "nfs_mount_path":'nfsMountPath',
+        "nfs_root_permissions":'nfsRootPermissions',
+        "nfs_root_squash":'nfsRootSquash',
+        "override_global_whitelist":'overrideGlobalWhitelist',
         "protocol_access":'protocolAccess',
         "qos":'qos',
         "s_3_access_path":'s3AccessPath',
+        "s_3_key_mapping_config":'s3KeyMappingConfig',
         "security_mode":'securityMode',
+        "share_permissions":'sharePermissions',
         "smb_mount_path":'smbMountPath',
         "smb_permissions_info":'smbPermissionsInfo',
         "stats":'stats',
         "storage_policy_override":'storagePolicyOverride',
         "subnet_whitelist":'subnetWhitelist',
+        "swift_project_domain":'swiftProjectDomain',
+        "swift_project_name":'swiftProjectName',
+        "swift_user_domain":'swiftUserDomain',
+        "swift_username":'swiftUsername',
         "tenant_id":'tenantId',
         "view_box_id":'viewBoxId',
         "view_box_name":'viewBoxName',
         "view_id":'viewId',
-        "view_lock_enabled":'viewLockEnabled',
         "view_protection":'viewProtection'
     }
 
@@ -190,11 +230,15 @@ class View(object):
                  create_time_msecs=None,
                  data_lock_expiry_usecs=None,
                  description=None,
+                 enable_fast_durable_handle=None,
                  enable_filer_audit_logging=None,
+                 enable_live_indexing=None,
                  enable_mixed_mode_permissions=None,
                  enable_nfs_view_discovery=None,
+                 enable_offline_caching=None,
                  enable_smb_access_based_enumeration=None,
                  enable_smb_encryption=None,
+                 enable_smb_oplock=None,
                  enable_smb_view_discovery=None,
                  enforce_smb_encryption=None,
                  file_extension_filter=None,
@@ -203,21 +247,30 @@ class View(object):
                  logical_quota=None,
                  logical_usage_bytes=None,
                  name=None,
+                 nfs_all_squash=None,
                  nfs_mount_path=None,
+                 nfs_root_permissions=None,
+                 nfs_root_squash=None,
+                 override_global_whitelist=None,
                  protocol_access=None,
                  qos=None,
                  s_3_access_path=None,
+                 s_3_key_mapping_config=None,
                  security_mode=None,
+                 share_permissions=None,
                  smb_mount_path=None,
                  smb_permissions_info=None,
                  stats=None,
                  storage_policy_override=None,
                  subnet_whitelist=None,
+                 swift_project_domain=None,
+                 swift_project_name=None,
+                 swift_user_domain=None,
+                 swift_username=None,
                  tenant_id=None,
                  view_box_id=None,
                  view_box_name=None,
                  view_id=None,
-                 view_lock_enabled=None,
                  view_protection=None):
         """Constructor for the View class"""
 
@@ -231,11 +284,15 @@ class View(object):
         self.create_time_msecs = create_time_msecs
         self.data_lock_expiry_usecs = data_lock_expiry_usecs
         self.description = description
+        self.enable_fast_durable_handle = enable_fast_durable_handle
         self.enable_filer_audit_logging = enable_filer_audit_logging
+        self.enable_live_indexing = enable_live_indexing
         self.enable_mixed_mode_permissions = enable_mixed_mode_permissions
         self.enable_nfs_view_discovery = enable_nfs_view_discovery
+        self.enable_offline_caching = enable_offline_caching
         self.enable_smb_access_based_enumeration = enable_smb_access_based_enumeration
         self.enable_smb_encryption = enable_smb_encryption
+        self.enable_smb_oplock = enable_smb_oplock
         self.enable_smb_view_discovery = enable_smb_view_discovery
         self.enforce_smb_encryption = enforce_smb_encryption
         self.file_extension_filter = file_extension_filter
@@ -244,21 +301,30 @@ class View(object):
         self.logical_quota = logical_quota
         self.logical_usage_bytes = logical_usage_bytes
         self.name = name
+        self.nfs_all_squash = nfs_all_squash
         self.nfs_mount_path = nfs_mount_path
+        self.nfs_root_permissions = nfs_root_permissions
+        self.nfs_root_squash = nfs_root_squash
+        self.override_global_whitelist = override_global_whitelist
         self.protocol_access = protocol_access
         self.qos = qos
         self.s_3_access_path = s_3_access_path
+        self.s_3_key_mapping_config = s_3_key_mapping_config
         self.security_mode = security_mode
+        self.share_permissions = share_permissions
         self.smb_mount_path = smb_mount_path
         self.smb_permissions_info = smb_permissions_info
         self.stats = stats
         self.storage_policy_override = storage_policy_override
         self.subnet_whitelist = subnet_whitelist
+        self.swift_project_domain = swift_project_domain
+        self.swift_project_name = swift_project_name
+        self.swift_user_domain = swift_user_domain
+        self.swift_username = swift_username
         self.tenant_id = tenant_id
         self.view_box_id = view_box_id
         self.view_box_name = view_box_name
         self.view_id = view_id
-        self.view_lock_enabled = view_lock_enabled
         self.view_protection = view_protection
 
 
@@ -285,7 +351,7 @@ class View(object):
         if dictionary.get('aliases') != None:
             aliases = list()
             for structure in dictionary.get('aliases'):
-                aliases.append(cohesity_management_sdk.models.view_alias_info.ViewAliasInfo.from_dictionary(structure))
+                aliases.append(cohesity_management_sdk.models.view_alias.ViewAlias.from_dictionary(structure))
         all_smb_mount_paths = dictionary.get('allSmbMountPaths')
         antivirus_scan_config = cohesity_management_sdk.models.antivirus_scan_config.AntivirusScanConfig.from_dictionary(dictionary.get('antivirusScanConfig')) if dictionary.get('antivirusScanConfig') else None
         basic_mount_path = dictionary.get('basicMountPath')
@@ -293,11 +359,15 @@ class View(object):
         create_time_msecs = dictionary.get('createTimeMsecs')
         data_lock_expiry_usecs = dictionary.get('dataLockExpiryUsecs')
         description = dictionary.get('description')
+        enable_fast_durable_handle = dictionary.get('enableFastDurableHandle')
         enable_filer_audit_logging = dictionary.get('enableFilerAuditLogging')
+        enable_live_indexing = dictionary.get('enableLiveIndexing')
         enable_mixed_mode_permissions = dictionary.get('enableMixedModePermissions')
         enable_nfs_view_discovery = dictionary.get('enableNfsViewDiscovery')
+        enable_offline_caching = dictionary.get('enableOfflineCaching')
         enable_smb_access_based_enumeration = dictionary.get('enableSmbAccessBasedEnumeration')
         enable_smb_encryption = dictionary.get('enableSmbEncryption')
+        enable_smb_oplock = dictionary.get('enableSmbOplock')
         enable_smb_view_discovery = dictionary.get('enableSmbViewDiscovery')
         enforce_smb_encryption = dictionary.get('enforceSmbEncryption')
         file_extension_filter = cohesity_management_sdk.models.file_extension_filter.FileExtensionFilter.from_dictionary(dictionary.get('fileExtensionFilter')) if dictionary.get('fileExtensionFilter') else None
@@ -306,11 +376,21 @@ class View(object):
         logical_quota = cohesity_management_sdk.models.quota_policy.QuotaPolicy.from_dictionary(dictionary.get('logicalQuota')) if dictionary.get('logicalQuota') else None
         logical_usage_bytes = dictionary.get('logicalUsageBytes')
         name = dictionary.get('name')
+        nfs_all_squash = cohesity_management_sdk.models.nfs_squash.NfsSquash.from_dictionary(dictionary.get('nfsAllSquash')) if dictionary.get('nfsAllSquash') else None
         nfs_mount_path = dictionary.get('nfsMountPath')
+        nfs_root_permissions = cohesity_management_sdk.models.nfs_root_permissions.NfsRootPermissions.from_dictionary(dictionary.get('nfsRootPermissions')) if dictionary.get('nfsRootPermissions') else None
+        nfs_root_squash = cohesity_management_sdk.models.nfs_squash.NfsSquash.from_dictionary(dictionary.get('nfsRootSquash')) if dictionary.get('nfsRootSquash') else None
+        override_global_whitelist = dictionary.get('overrideGlobalWhitelist')
         protocol_access = dictionary.get('protocolAccess')
         qos = cohesity_management_sdk.models.qo_s.QoS.from_dictionary(dictionary.get('qos')) if dictionary.get('qos') else None
         s_3_access_path = dictionary.get('s3AccessPath')
+        s_3_key_mapping_config = dictionary.get('s3KeyMappingConfig')
         security_mode = dictionary.get('securityMode')
+        share_permissions = None
+        if dictionary.get('sharePermissions') != None:
+            share_permissions = list()
+            for structure in dictionary.get('sharePermissions'):
+                share_permissions.append(cohesity_management_sdk.models.smb_permission.SmbPermission.from_dictionary(structure))
         smb_mount_path = dictionary.get('smbMountPath')
         smb_permissions_info = cohesity_management_sdk.models.smb_permissions_info.SmbPermissionsInfo.from_dictionary(dictionary.get('smbPermissionsInfo')) if dictionary.get('smbPermissionsInfo') else None
         stats = cohesity_management_sdk.models.view_stats.ViewStats.from_dictionary(dictionary.get('stats')) if dictionary.get('stats') else None
@@ -320,11 +400,14 @@ class View(object):
             subnet_whitelist = list()
             for structure in dictionary.get('subnetWhitelist'):
                 subnet_whitelist.append(cohesity_management_sdk.models.subnet.Subnet.from_dictionary(structure))
+        swift_project_domain = dictionary.get('swiftProjectDomain', None)
+        swift_project_name = dictionary.get('swiftProjectName', None)
+        swift_user_domain = dictionary.get('swiftUserDomain')
+        swift_username = dictionary.get('swiftUsername')
         tenant_id = dictionary.get('tenantId')
         view_box_id = dictionary.get('viewBoxId')
         view_box_name = dictionary.get('viewBoxName')
         view_id = dictionary.get('viewId')
-        view_lock_enabled = dictionary.get('viewLockEnabled')
         view_protection = cohesity_management_sdk.models.view_protection.ViewProtection.from_dictionary(dictionary.get('viewProtection')) if dictionary.get('viewProtection') else None
 
         # Return an object of this model
@@ -337,11 +420,15 @@ class View(object):
                    create_time_msecs,
                    data_lock_expiry_usecs,
                    description,
+                   enable_fast_durable_handle,
                    enable_filer_audit_logging,
+                   enable_live_indexing,
                    enable_mixed_mode_permissions,
                    enable_nfs_view_discovery,
+                   enable_offline_caching,
                    enable_smb_access_based_enumeration,
                    enable_smb_encryption,
+                   enable_smb_oplock,
                    enable_smb_view_discovery,
                    enforce_smb_encryption,
                    file_extension_filter,
@@ -350,21 +437,30 @@ class View(object):
                    logical_quota,
                    logical_usage_bytes,
                    name,
+                   nfs_all_squash,
                    nfs_mount_path,
+                   nfs_root_permissions,
+                   nfs_root_squash,
+                   override_global_whitelist,
                    protocol_access,
                    qos,
                    s_3_access_path,
+                   s_3_key_mapping_config,
                    security_mode,
+                   share_permissions,
                    smb_mount_path,
                    smb_permissions_info,
                    stats,
                    storage_policy_override,
                    subnet_whitelist,
+                   swift_project_domain,
+                   swift_project_name,
+                   swift_user_domain,
+                   swift_username,
                    tenant_id,
                    view_box_id,
                    view_box_name,
                    view_id,
-                   view_lock_enabled,
                    view_protection)
 
 
