@@ -27,7 +27,7 @@ class VmwareProtectionSource(object):
             'kConnected', 'kDisconnected', 'kInacccessible', etc. 'kConnected'
             indicates that server has access to virtual machine.
             'kDisconnected' indicates that server is currently disconnected to
-            virtual machine. 'kInacccessible' indicates that one or more
+            virtual machine. 'kInaccessible' indicates that one or more
             configuration files are inacccessible. 'kInvalid' indicates that
             virtual machine configuration is invalid. 'kOrphaned' indicates
             that virtual machine is no longer registered on the host it is
@@ -50,6 +50,8 @@ class VmwareProtectionSource(object):
             Linux operating system. 'kWindows' indicates the Microsoft Windows
             operating system. 'kAix' indicates the IBM AIX operating system.
             'kSolaris' indicates the Oracle Solaris operating system.
+            'kSapHana' indicates the Sap Hana database system developed by SAP
+            SE. 'kOther' indicates the other types of operating system.
         id (VmwareObjectId): Specifies a unique Protection Source id across
             Cohesity Clusters. It is derived from the id of the VMware
             Protection Source.
@@ -93,7 +95,7 @@ class VmwareProtectionSource(object):
             VMware protection source type. 'kTag' indocates a tag entity in a
             VMware protection source type. 'kOpaqueNetwork' indicates a opaque
             network which is created and managed by an entity outside of
-            vSphere. 'kvCloudDirector' indicates a vCloud director entity in a
+            vSphere. 'kVCloudDirector' indicates a vCloud director entity in a
             VMware protection source type. 'kOrganization' indicates an
             Organization under a vCD in a VMware protection source type.
             'kVirtualDatacenter' indicates a virtual datacenter entity in a
@@ -104,6 +106,8 @@ class VmwareProtectionSource(object):
             associated with the vApp in a VMware protection source type.
         vcloud_director_info (list of VcloudDirectorInfo): Specifies an array
             of vCenters to be registered
+        version (string): For vCenter and ESXi, this will show the software
+            version. For VMs, this will show the hardware version.
         virtual_disks (list of VirtualDiskInfo): Specifies an array of virtual
             disks that are part of the Virtual Machine. This is populated for
             entities of type 'kVirtualMachine'.
@@ -126,6 +130,7 @@ class VmwareProtectionSource(object):
         "tools_running_status":'toolsRunningStatus',
         "mtype":'type',
         "vcloud_director_info":'vCloudDirectorInfo',
+        "version":'version',
         "virtual_disks":'virtualDisks'
     }
 
@@ -144,6 +149,7 @@ class VmwareProtectionSource(object):
                  tools_running_status=None,
                  mtype=None,
                  vcloud_director_info=None,
+                 version=None,
                  virtual_disks=None):
         """Constructor for the VmwareProtectionSource class"""
 
@@ -162,6 +168,7 @@ class VmwareProtectionSource(object):
         self.tools_running_status = tools_running_status
         self.mtype = mtype
         self.vcloud_director_info = vcloud_director_info
+        self.version = version
         self.virtual_disks = virtual_disks
 
 
@@ -209,6 +216,7 @@ class VmwareProtectionSource(object):
             vcloud_director_info = list()
             for structure in dictionary.get('vCloudDirectorInfo'):
                 vcloud_director_info.append(cohesity_management_sdk.models.vcloud_director_info.VcloudDirectorInfo.from_dictionary(structure))
+        version = dictionary.get('version')
         virtual_disks = None
         if dictionary.get('virtualDisks') != None:
             virtual_disks = list()
@@ -230,6 +238,7 @@ class VmwareProtectionSource(object):
                    tools_running_status,
                    mtype,
                    vcloud_director_info,
+                   version,
                    virtual_disks)
 
 
